using System;
using System.Collections.Generic;
using System.Text;

namespace Microsoft.eResearch.GenePattern.Common
{
    /// <summary>
    /// Class Storing the State of Ribbon
    /// </summary>
    public class ControlState : DomainBase
    {
        #region Variable Declaration

        /// <summary>
        /// Store for Active Connection for document
        /// </summary>
        private string _activeConnection = string.Empty;

        /// <summary>
        /// Status of Connection Pane
        /// </summary>
        private bool _isConnectionPaneUpdated = true;

        /// <summary>
        /// Store the CheckBox Status of Wizard Free UI
        /// </summary>
        private bool _isWizardFreeUI = true;

        /// <summary>
        /// Store for DashBoardButton  state
        /// </summary>
        private bool _isDashBoardButtonPressed;

        /// <summary>
        /// Store for ViewAssociation  state
        /// </summary>
        private bool _isViewAssociationButtonPressed;

        /// <summary>
        /// Store for AssociateButton  state
        /// </summary>
        private bool _isAssociateButtonPressed;

        /// <summary>
        /// Store for InsertGenePattern  state
        /// </summary>
        private bool _isInsertGenePatternButtonPressed;

        /// <summary>
        /// Store for ProtectDocument  state
        /// </summary>
        private bool _isProtectDocumentButtonPressed;

        /// <summary>
        /// Store for RerunPipeline  state
        /// </summary>
        private bool _isRerunPipelineButtonPressed;

        /// <summary>
        /// Store for Connections  state
        /// </summary>
        private bool _isConnectionsButtonPressed;


        #endregion

        #region Properties

        /// <summary>
        /// Gets or sets a value indicating whether this instance is connection pane updated.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is connection pane updated; otherwise, <c>false</c>.
        /// </value>
        public bool IsConnectionPaneUpdated
        {
            get { return _isConnectionPaneUpdated; }
            set { _isConnectionPaneUpdated = value; }
        }

        /// <summary>
        /// Gets or sets the drop down active connection.
        /// </summary>
        /// <value>The drop down active connection.</value>
        public string DropDownActiveConnection
        {
            get { return _activeConnection; }
            set { _activeConnection = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is wizard free UI.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is wizard free UI; otherwise, <c>false</c>.
        /// </value>
        public bool IsWizardFreeUI
        {
            get { return _isWizardFreeUI; }
            set { _isWizardFreeUI = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is dash board button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is dash board button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsDashBoardButtonPressed
        {
            get { return _isDashBoardButtonPressed; }
            set { _isDashBoardButtonPressed = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is connections button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is connections button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsConnectionsButtonPressed
        {
            get { return _isConnectionsButtonPressed; }
            set { _isConnectionsButtonPressed = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is rerun pipeline button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is rerun pipeline button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsRerunPipelineButtonPressed
        {
            get { return _isRerunPipelineButtonPressed; }
            set { _isRerunPipelineButtonPressed = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is protect document button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is protect document button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsProtectDocumentButtonPressed
        {
            get { return _isProtectDocumentButtonPressed; }
            set { _isProtectDocumentButtonPressed = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is insert gene pattern button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is insert gene pattern button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsInsertGenePatternButtonPressed
        {
            get { return _isInsertGenePatternButtonPressed; }
            set { _isInsertGenePatternButtonPressed = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is associate button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is associate button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsAssociateButtonPressed
        {
            get { return _isAssociateButtonPressed; }
            set { _isAssociateButtonPressed = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is view association button pressed.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is view association button pressed; otherwise, <c>false</c>.
        /// </value>
        public bool IsViewAssociationButtonPressed
        {
            get { return _isViewAssociationButtonPressed; }
            set { _isViewAssociationButtonPressed = value; }
        }
        #endregion

        #region Public Methods

        /// <summary>
        /// Gets the state of the control.
        /// </summary>
        /// <param name="controlKey">The control key.</param>
        /// <returns></returns>
        public bool GetControlState(ControlKey controlKey)
        {
            switch (controlKey)
            {
                case ControlKey.AssociatePipelineButton:
                    return _isAssociateButtonPressed;
                case ControlKey.ConnectionsButton:
                    return _isConnectionsButtonPressed;
                case ControlKey.DashBoardButton:
                    return _isDashBoardButtonPressed;
                case ControlKey.InsertGenePatternLinkButton:
                    return _isInsertGenePatternButtonPressed;
                case ControlKey.ProtectDocumentButton:
                    return _isProtectDocumentButtonPressed;
                case ControlKey.RerunPipelineButton:
                    return _isRerunPipelineButtonPressed;
                case ControlKey.ViewAssociationButton:
                    return _isViewAssociationButtonPressed;
                default:
                    return false;
            }
        }

        /// <summary>
        /// Sets the state of the control.
        /// </summary>
        /// <param name="controlKey">The control key.</param>
        /// <param name="isPressed">if set to <c>true</c> [is pressed].</param>
        public void SetControlState(ControlKey controlKey, bool isPressed)
        {
            switch (controlKey)
            {
                case ControlKey.AssociatePipelineButton:
                    _isAssociateButtonPressed = isPressed;
                    break;
                case ControlKey.ConnectionsButton:
                    _isConnectionsButtonPressed = isPressed;
                    break;
                case ControlKey.DashBoardButton:
                    _isDashBoardButtonPressed = isPressed;
                    break;
                case ControlKey.InsertGenePatternLinkButton:
                    _isInsertGenePatternButtonPressed = isPressed;
                    break;
                case ControlKey.ProtectDocumentButton:
                    _isProtectDocumentButtonPressed = isPressed;
                    break;
                case ControlKey.RerunPipelineButton:
                    _isRerunPipelineButtonPressed = isPressed;
                    break;
                case ControlKey.ViewAssociationButton:
                    _isViewAssociationButtonPressed = isPressed;
                    break;
              
            }
        }

        #endregion
    }
}
