using System;
using System.Collections.Generic;
using System.Drawing;
using System.Runtime.InteropServices;
using System.Text;
using System.IO;
using System.Reflection;

namespace Microsoft.eResearch.GenePattern.Common
{
   [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1705:LongAcronymsShouldBePascalCased"), StructLayout(LayoutKind.Sequential)]
   struct SHFILEINFO
   {
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Security", "CA2111:PointersShouldNotBeVisible")]
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1051:DoNotDeclareVisibleInstanceFields")]
      public IntPtr hIcon;
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Security", "CA2111:PointersShouldNotBeVisible")]
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1051:DoNotDeclareVisibleInstanceFields")]
      public IntPtr iIcon;
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1051:DoNotDeclareVisibleInstanceFields")]
      public uint dwAttributes;
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1051:DoNotDeclareVisibleInstanceFields")]
      [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 260)]
      public string szDisplayName;
      [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1051:DoNotDeclareVisibleInstanceFields")]
      [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 80)]
      public string szTypeName;
   };

   class Win32
   {
      private Win32()
      {

      }

      public const uint SHGFI_ICON = 0x100;
      public const uint SHGFI_LARGEICON = 0x0; // Modify SHGFI_ICON, causing the function to retrieve the file's large icon. The SHGFI_ICON flag must also be set.
      public const uint SHGFI_SMALLICON = 0x1; // Modify SHGFI_ICON, causing the function to retrieve the file's small icon. Also used to modify SHGFI_SYSICONINDEX, causing the function to return the handle to the system image list that contains small icon images. The SHGFI_ICON and/or SHGFI_SYSICONINDEX flag must also be set.
      public const uint SHGFI_USEFILEATTRIBUTES = 0x10; // Indicates that the function should not attempt to access the file specified by pszPath. Rather, it should act as if the file specified by pszPath exists with the file attributes passed in dwFileAttributes. This flag cannot be combined with the SHGFI_ATTRIBUTES, SHGFI_EXETYPE, or SHGFI_PIDL flags.

      /// <summary>
      /// SHs the get file info.
      /// </summary>
      /// <param name="pszPath">The PSZ path.</param>
      /// <param name="dwFileAttributes">The dw file attributes.</param>
      /// <param name="psfi">The psfi.</param>
      /// <param name="cbSizeFileInfo">The cb size file info.</param>
      /// <param name="uFlags">The u flags.</param>
      /// <returns></returns>
       [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1060:MovePInvokesToNativeMethodsClass"), DllImport("shell32.dll")]
      public static extern IntPtr SHGetFileInfo(string pszPath, uint dwFileAttributes, ref SHFILEINFO psfi, uint cbSizeFileInfo, uint uFlags);

   }

   /// <summary>
   /// Helper class for default application icons
   /// </summary>
   public static class DefaultApplicationIconHelper
   {
       [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1060:MovePInvokesToNativeMethodsClass"),
       System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Interoperability", "CA1414:MarkBooleanPInvokeArgumentsWithMarshalAs"), DllImport("user32.dll", CharSet = CharSet.Auto)]
      private static extern bool DestroyIcon(IntPtr handle);

      /// <summary>
      /// Gets the small default icon for the file extension.
      /// </summary>
      /// <param name="fileExtension">The file extension.</param>
      /// <returns>a Bitmap representing the icon</returns>
      public static Bitmap GetSmallIcon(string fileExtension)
      {
         return GetIcon(fileExtension, false);
      }

      /// <summary>
      /// Gets the large default icon for the file extension.
      /// </summary>
      /// <param name="fileExtension">The file extension.</param>
      /// <returns>a Bitmap representing the icon</returns>
      public static Bitmap GetLargeIcon(string fileExtension)
      {
         return GetIcon(fileExtension, true);
      }

      private static Bitmap GetIcon(string fileExtension, bool largeIcon)
      {
         SHFILEINFO shinfo = new SHFILEINFO();

         //set the size of the requested icon to return
         uint iconSize = largeIcon ? Win32.SHGFI_LARGEICON : Win32.SHGFI_SMALLICON;
         //Use this to get the icon Icon, the Win32.SHGFI_ICON flag is needed regardless of size
         // if the SHGFI_USEFILEATTRIBUTES flag is set the file need not exist, use only the extension
         Win32.SHGetFileInfo(fileExtension, 0, ref shinfo, (uint)Marshal.SizeOf(shinfo), Win32.SHGFI_ICON | iconSize | Win32.SHGFI_USEFILEATTRIBUTES);

         Bitmap bitmap = null;
         if (shinfo.hIcon != IntPtr.Zero)
         {
            Icon myIcon = Icon.FromHandle(shinfo.hIcon);
            bitmap = myIcon.ToBitmap();
            DestroyIconHandle(myIcon.Handle);
            DestroyIconHandle(shinfo.hIcon);
            myIcon.Dispose();
         }
         return bitmap;
      }

      /// <summary>
      /// Destroys the icon.
      /// </summary>
      /// <param name="handle">The handle.</param>
      public static void DestroyIconHandle(IntPtr handle)
      {
         DestroyIcon(handle);
      }
   }
}
