using System.IO;

namespace Microsoft.eResearch.GenePattern.Common
{
    /// <summary>
    /// Represents the Input File that is chosen by the user for a Job Parameter.
    /// If the file is a local file or a file from the word document, the file 
    /// contents will be stored in the "Data" property
    /// </summary>
    public class InputFile : DomainBase
    {
        private string name;
        private bool isLinked;
        private string contents;
        private string path;


        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>The name.</value>
        public string Name
        {
            get { return name; }
            set { name = value; }
        }


        /// <summary>
        /// Gets or sets a value indicating whether this instance is linked (most probably through an URI).
        /// </summary>
        /// <value><c>true</c> if this instance is linked(through an URI); otherwise, <c>false</c>.</value>
        public bool IsLinked
        {
            get { return isLinked; }
            set { isLinked = value; }
        }


        /// <summary>
        /// Gets or sets the contents of the File.
        /// </summary>
        /// <value>The contents of the Input File.</value>
        public string Contents
        {
            get { return contents; }
            set { contents = value; }
        }

        /// <summary>
        /// Gets or sets the path.
        /// </summary>
        /// <value>The path.</value>
        public string Path
        {
            get { return path; }
            set { path = value; }
        }
    }
}