using System;
using System.Collections.Generic;
using System.Xml.Serialization;

namespace Microsoft.eResearch.GenePattern.Common
{
    /// <summary>
    /// A JobParameter is a name and value that is specified to invoke a job on the server.
    /// </summary>
    [XmlInclude(typeof(InternalFile))]
    [XmlInclude(typeof(SerializableUri))]
    [XmlInclude(typeof(LocalFile))]
    // let xml serializer know that InteralFile might be needed as
    // is is a possible type for values of the paramValue field
    public class JobParameter : DomainBase
    {
        private string name;
        private object paramValue;
        private object previousParamValue;
        private bool optional;

        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>The name.</value>
        public string Name
        {
            get { return name; }
            set { name = value; }
        }

        /// <summary>
        /// Gets or sets the param value.
        /// </summary>
        /// <remarks>The property should hold objects of type string, InternalFile, LocalFile or Uri</remarks>
        /// <value>The param value.</value>
        public object ParamValue
        {
            get { return paramValue; }
            set { paramValue = value; }
        }

        /// <summary>
        /// Gets or sets the previous param value.
        /// </summary>
        /// <value>The previous param value.</value>
        public object PreviousParamValue
        {
            get { return previousParamValue; }
            set { previousParamValue = value; }
        }

        /// <summary>
        /// Gets or sets the the optional.
        /// </summary>
        /// <value>The optional</value>
        public bool Optional
        {
            get { return optional; }
            set { optional = value; }
        }

        /// <summary>
        /// Creates a new object that is a copy of the current instance.
        /// </summary>
        /// <returns>
        /// A new object that is a copy of this instance.
        /// </returns>
        public override object Clone()
        {
            JobParameter parameter = new JobParameter();
            parameter.name = CopyString(this.name);
            parameter.Optional = this.Optional;

            if (paramValue is ICloneable)
            {
                parameter.paramValue = ((ICloneable) paramValue).Clone();
            }
            if(paramValue is Uri)
            {
                parameter.paramValue = new SerializableUri(paramValue.ToString());
            }
            if(paramValue is string)
            {
                parameter.paramValue = CopyString(this.paramValue.ToString());
            }
            return parameter;
        }
    }
}
