using System.Collections.Generic;

namespace Microsoft.eResearch.GenePattern.Common
{
    
    /// <summary>
    /// The various PipelineParameter types
    /// </summary>
    public enum ParameterType
    {
        /// <summary>
        /// Reprsents an Input File (A matlab script, Java file etc)
        /// </summary>
        InputFile,
        /// <summary>
        /// Represents an output file (for storing data)
        /// </summary>
        OutputFile,
        /// <summary>
        /// Represents a string
        /// </summary>
        String,
        /// <summary>
        /// Represents a string collection
        /// </summary>
        StringCollection,
        /// <summary>
        /// Represents a number
        /// </summary>
        Number
    }

    /// <summary>
    /// A PipelineParameter is a definition of a parameter needed to run the pipeline in a job on the server.  
    /// </summary>
    public class PipelineParameter : DomainBase
    {
        private string name;
        private string shortName;
        private string description;
        private ParameterType type;
        private bool optional;
        private readonly List<Choice> choices = new List<Choice>();

        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>The name.</value>
        public string Name
        {
            get { return name; }
            set { name = value; }
        }

        /// <summary>
        /// Gets or sets the description.
        /// </summary>
        /// <value>The description.</value>
        public string Description
        {
            get { return description; }
            set { description = value; }
        }

        /// <summary>
        /// Gets or sets the type.
        /// </summary>
        /// <value>The type.</value>
        public ParameterType Type
        {
            get { return type; }
            set { type = value; }
        }

        /// <summary>
        /// Gets the choices.
        /// </summary>
        /// <value>The choices.</value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists")]
        public List<Choice> Choices
        {
            get { return choices; }
        }

        /// <summary>
        /// Gets or sets the short name of the parameter.
        /// </summary>
        /// <value>The name of the short.</value>
        public string ShortName
        {
            get { return shortName; }
            set { shortName = value; }
        }

        public bool Optional
        {
            get { return optional; }
            set { optional = value; }
        }


        /// <summary>
        /// Retrieves the Choice corresponding to the 
        /// specified value.
        /// </summary>
        /// <param name="paramValue"></param>
        /// <returns>the found <c>Choice</c> instance or null</returns>
        public Choice GetChoice(string paramValue)
        {
            foreach (Choice choice in choices)
            {
                if (choice.Value == paramValue)
                    return choice;
            }

            return null;
        }
    }
}
