using System;
using System.Collections.Generic;
using System.Text;
using System.Xml.Serialization;

namespace Microsoft.eResearch.GenePattern.Common
{
    public class Rerun : DomainBase
    {
        private Connection connection;
        private bool showVisualizers;
        private Job job;
        private bool promptForDelete;
        private bool promptForReconnect;
        private string serverName;
        private string username;
        private int port;
        private bool insertedToAppedix = false;

        public Rerun()
        {
            job = new Job();
            showVisualizers = true;
            promptForDelete = true;
            promptForReconnect = true;
        }

        public Rerun(Connection conn)
        {
            job = new Job();
            this.SetConnection(conn);
            showVisualizers = true;
            promptForDelete = true;
            promptForReconnect = true;
        }

        [XmlIgnore]
        [DoNotCompare]
        //[DoNotClone]
        public Connection Connection
        {
            get
            {
                if(connection == null && serverName != null && port != 0)
                {
                    connection = new Connection("Rerun Connection",serverName,username,"",port);
                }
                return connection;
                
            }
            set { connection = value; }
        }

        public bool ShowVisualizers
        {
            get { return showVisualizers; }
            set { showVisualizers = value; }
        }

        public Job Job
        {
            get { return job; }
            set { job = value; }
        }

        /// Will be true if we should prompt the user to delete this rerun if it's missing
        /// Will be fasle if user has already been prompted and elected to not delete it
        /// *Note that this will reset on every deserialization as it is not saved
        [XmlIgnore]
        [DoNotCompare]
        [DoNotClone]
        public bool PromptForDelete
        {
            get { return promptForDelete; }
            set { promptForDelete = value; }
        }

        public string ServerName
        {
            get { return serverName; }
            set { serverName = value; }
        }

        public int Port
        {
            get { return port; }
            set { port = value; }
        }

        [XmlIgnore]
        [DoNotClone]
        [DoNotCompare]
        public bool PromptForReconnect
        {
            get { return promptForReconnect; }
            set { promptForReconnect = value; }
        }

        public string Username
        {
            get { return username; }
            set { username = value; }
        }

        public bool InsertedToAppedix
        {
            get { return insertedToAppedix; }
            set { insertedToAppedix = value; }
        }

        public void SetConnection(Connection c)
        {
            Connection = c;
            Username = Connection.Username;
            Port = Connection.Port;
            ServerName = Connection.ServerName;
        }
    }
}
