using System;

namespace Microsoft.eResearch.GenePattern.Common
{

    /// <summary>
    /// A result is an object returned by a job run on the genepattern server.  It is generally a file of some kind.
    /// </summary>
    public class Result : BaseFile
    {
        private string url;
        private byte[] content;
        private int sourceStep;
        private int outputIndex;
        private bool isLargeSize;

        /// <summary>
        /// Gets or sets the URL.
        /// </summary>
        /// <value>The URL.</value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1056:UriPropertiesShouldNotBeStrings")]
        public string Url
        {
            get { return url; }
            set { url = value; }
        }

        /// <summary>
        /// Gets or sets the content.
        /// </summary>
        /// <value>The content.</value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Performance", "CA1819:PropertiesShouldNotReturnArrays")]
        public byte[] Content
        {
            get { return content; }
            set
            {
                content = value;
                if (content != null)
                {
                    if (content.Length > DefaultSetting.LargeFileSize)
                    {
                        isLargeSize = true;
                    }
                }
            }
        }

        /// <summary>
        /// Gets or sets the source step.
        /// </summary>
        /// <value>The source step.</value>
        public int SourceStep
        {
            get { return sourceStep; }
            set { sourceStep = value; }
        }

        /// <summary>
        /// Gets or sets the index of the output.
        /// </summary>
        /// <value>The index of the output.</value>
        public int OutputIndex
        {
            get { return outputIndex; }
            set { outputIndex = value; }
        }

        /// <summary>
        /// Gets or sets the size of the is large.
        /// </summary>
        /// <value>The size of the is large.</value>
        public bool IsLargeSize
        {
            get { return isLargeSize; }
        }
    }
}
