using System;
using System.Collections.Generic;
using System.Text;
using System.Xml.Serialization;

namespace Microsoft.eResearch.GenePattern.Common
{

    /// <summary>
    /// Class to Get/Perform operation on URI
    /// </summary>
    public class SerializableUri : DomainBase
    {
        private Uri _uri;

        /// <summary>
        /// Initializes a new instance of the <see cref="SerializableUri"/> class.
        /// </summary>
        public SerializableUri()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SerializableUri"/> class.
        /// </summary>
        /// <param name="uri">The URI.</param>
        public SerializableUri(string uri)
        {
            _uri = new Uri(uri);
        }

        /// <summary>
        /// Gets or sets the serialize URI.
        /// </summary>
        /// <value>The serialize URI.</value>
        public string SerializeUri
        {
            get { return _uri.ToString(); }
            set { _uri = new Uri(value); }
        }

        /// <summary>
        /// Gets or sets the URI.
        /// </summary>
        /// <value>The URI.</value>
        [XmlIgnore]
        [DoNotClone]
        [DoNotCompare]
        public Uri Uri
        {
            get { return _uri; }
            set { _uri = value; }
        }


        /// <summary>
        /// Returns a <see cref="T:System.String"></see> that represents the current <see cref="T:System.Object"></see>.
        /// </summary>
        /// <returns>
        /// A <see cref="T:System.String"></see> that represents the current <see cref="T:System.Object"></see>.
        /// </returns>
        public override string ToString()
        {
            return _uri.ToString();
        }
    }
}
