using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Text;
using System.Xml.Serialization;
using Microsoft.eResearch.ScientificAddIn.Common;

namespace Microsoft.eResearch.GenePattern.Common
{
    /// <summary>
    /// Data stored per user
    /// </summary>
    public class UserData
    {
        #region Fields

        private SerializableDictionary<string, Connection> connectionDictionary = new SerializableDictionary<string, Connection>();
        private string currentConnectionName;
        private bool showAssociationWizardIntroPage = true;
        private bool showRerunWizardIntroPage = true;
        private bool hasShownIntroMessage;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="UserData"/> class.
        /// </summary>
        public UserData()
        {
        }

        #endregion

        #region Public Properties
        /// <summary>
        /// </summary>
        /// <value>The connections.</value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
        public SerializableDictionary<string, Connection> Connections
        {
            get
            {
                return connectionDictionary;
            }
            set
            {
                connectionDictionary = value;
            }
        }

        /// <summary>
        /// Gets or sets the name of the current connection.
        /// </summary>
        /// <value>The name of the current connection.</value>
        public string CurrentConnectionName
        {
            get { return currentConnectionName; }
            set { currentConnectionName = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether to show wizard intro page.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if system shall show wizard intro page; otherwise, <c>false</c>.
        /// </value>
        public bool ShowAssociationWizardIntroPage
        {
            get { return showAssociationWizardIntroPage; }
            set { showAssociationWizardIntroPage = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether show pipeline rerun wizard intro page.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if intro page shall be shown; otherwise, <c>false</c>.
        /// </value>
        public bool ShowRerunWizardIntroPage
        {
            get { return showRerunWizardIntroPage; }
            set { showRerunWizardIntroPage = value; }
        }

        /// <summary>
        /// Gets or sets the value indicating whether or not the introduction message has been shown
        /// </summary>
        public bool HasShownIntroMessage
        {
            get { return hasShownIntroMessage; }
            set { hasShownIntroMessage = value; }
        }

        #endregion
    }
}
