using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// The model used to store new pipelines and pipeline associations while
    /// creating them
    /// </summary>
    public class AssociatePipelineWizardModel : DomainBase, IWizardModel
    {
        private List<Pipeline> pipelines;
        private List<PipelineAssociation> pipelineAssociations;

        /// <summary>
        /// Initializes a new instance of the <see cref="AssociatePipelineWizardModel"/> class.
        /// </summary>
        public AssociatePipelineWizardModel()
        {
            pipelineAssociations = new List<PipelineAssociation>();
            pipelines = new List<Pipeline>();
        }

        /// <summary>
        /// Adds the empty data.
        /// </summary>
        public void AddEmptyData()
        {
            pipelineAssociations.Add(new PipelineAssociation());
            pipelines.Add(new Pipeline());
        }

        /// <summary>
        /// Gets or sets the latest pipeline.
        /// </summary>
        /// <value>The pipeline.</value>
        [DoNotClone]
        public Pipeline Pipeline
        {
            get
            {
                if (Pipelines.Count == 0)
                    return null;
                else
                    return Pipelines[Pipelines.Count-1];
            }
            set { Pipelines[Pipelines.Count - 1] = value; }
        }

        /// <summary>
        /// Gets or sets the pipeline latest association.
        /// </summary>
        /// <value>The pipeline association.</value>
        [DoNotClone]
        public PipelineAssociation PipelineAssociation
        {
            get
            {
                if (PipelineAssociations.Count == 0)
                    return null;
                else
                    return PipelineAssociations[PipelineAssociations.Count-1];
            }
            set { PipelineAssociations[PipelineAssociations.Count - 1] = value; }
        }

        /// <summary>
        /// Gets the pipelines.
        /// </summary>
        /// <value>The pipelines.</value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists")]
        public List<Pipeline> Pipelines
        {
            get { return pipelines; }
            set { pipelines = value; }
        }

        /// <summary>
        /// Gets the pipeline associations.
        /// </summary>
        /// <value>The pipeline associations.</value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists")]
        public List<PipelineAssociation> PipelineAssociations
        {
            get { return pipelineAssociations; }
            set { pipelineAssociations = value; }
        }

    }
}
