using System;
using System.Collections.Generic;
using System.Text;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// The base class for commands, especially from UI events of the Ribbon
    /// </summary>
    public abstract class Command
    {
        private readonly IController controllerInstance;

        /// <summary>
        /// Gets the controller instance.
        /// </summary>
        /// <value>The controller instance.</value>
        protected internal IController ControllerInstance
        {
            get { return controllerInstance; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Command"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        protected Command(IController controller)
        {
            this.controllerInstance = controller;    
        }

        /// <summary>
        /// Invokes the command.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        public abstract void Invoke(string controlId);

        /// <summary>
        /// Gets a value indicating whether the originating control needs to be invalidated.
        /// </summary>
        /// <value><c>true</c> if the control needs to be invalidated; otherwise, <c>false</c>.</value>
        public virtual bool NeedsInvalidate
        {
            get
            {
                return false;
            }
        }
    }
}
