using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
   /// <summary>
   /// The command to be invoked by the Dashbaord button in the ribbon
   /// </summary>
   public class DashboardCommand : Command
   {
      /// <summary>
      /// Initializes a new instance of the <see cref="DashboardCommand"/> class.
      /// </summary>
      /// <param name="controller">The controller.</param>
      public DashboardCommand(IController controller)
         : base(controller)
      {
      }

      /// <summary>
      /// Invokes the command assuming the toggle buttin is pressed
      /// </summary>
      /// <param name="controlId">The originating control id.</param>
      public override void Invoke(string controlId)
      {
         Invoke(controlId, true);
      }

      /// <summary>
      /// Invokes the command.
      /// </summary>
      /// <param name="controlId">The originating control id.</param>
      /// <param name="isPressed">if set to <c>true</c> toggle button is pressed.</param>
      public void Invoke(string controlId, bool isPressed)
      {
         if (!ControllerInstance.ActiveDocumentIsNull)
         {
            string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.Dashboard);
            if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
            {
               DashboardUserControl userControl = new DashboardUserControl();
               userControl.Controller = ControllerInstance;
               ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);


               ReadOnlyCollection<PipelineAssociation> pipelineAssociationsList =
                   ControllerInstance.GetAllPipelineAssociations();
               ReadOnlyCollection<ContentItem> contentItems = ControllerInstance.GetContentItems(pipelineAssociationsList, string.Empty);
               userControl.DisplayPipelineAssociations(pipelineAssociationsList, contentItems);
            }
            ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
            ControllerInstance.CheckFirstTimeRunning();
         }
      }

      /// <summary>
      /// Gets a value indicating whether the originating control needs to be invalidated.
      /// </summary>
      /// <value>
      /// 	<c>true</c> if the control needs to be invalidated; otherwise, <c>false</c>.
      /// </value>
      public override bool NeedsInvalidate
      {
         get
         {
            return true; // since the toggle action can get canceled, we need to requery always.
         }

      }
   }
}
