using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;
using System.Collections.ObjectModel;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// The command associated with the Delete GenePattern Data button of the 
    /// GenePattern tab in the Ribbon
    /// </summary>
    public class DeleteGenePatternDataCommand : Command
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="DeleteGenePatternDataCommand"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        public DeleteGenePatternDataCommand(IController controller)
            : base(controller)
        {
        }

        /// <summary>
        /// Invokes the command.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1300:SpecifyMessageBoxOptions")]
        public override void Invoke(string controlId)
        {
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                if (!ControllerInstance.CheckDocumentProtection())
                {
                    ReadOnlyCollection<PipelineAssociation> pipelineAssociationList = ControllerInstance.GetAllPipelineAssociations();
                    if (pipelineAssociationList.Count != 0)
                    {
                        if (DialogResult.Yes == MessageBox.Show(Resources.DELETE_ALL_PIPELINE_ASSOCIATIONS_QUESTION, Resources.GENEPATTREN_MSG_HEADER, MessageBoxButtons.YesNo,
                                                               MessageBoxIcon.Warning, MessageBoxDefaultButton.Button2))
                        {
                            ControllerInstance.DeleteAllPipelineassociations(pipelineAssociationList);
                            ControllerInstance.CleanDataStore();
                            ControllerInstance.UpdatePipelineAssociationsDisplay();
                            ControllerInstance.DeleteAppendix();
                        }
                    }
                    else
                    {
                        MessageBox.Show(Resources.PIPELINE_ASSOCIATION_NOT_PRESENT, Resources.GENEPATTREN_MSG_HEADER,
                            MessageBoxButtons.OK, MessageBoxIcon.Information);
                    }
                }
            }
        }
    }
}


