using System.Windows.Forms;
namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// The command associated with the Associate PipelineName button of the 
    /// GenePattern tab in the Ribbon
    /// </summary>
    public class PaneAsscoiatePipelineCommand : Command
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AssociatePipelineCommand"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        public PaneAsscoiatePipelineCommand(IController controller)
            : base(controller)
        {
        }

        /// <summary>
        /// Invokes the command assuming toggle button is pressed.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        public override void Invoke(string controlId)
        {
            Invoke(true);
        }

        /// <summary>
        /// Invokes the specified is pressed.
        /// </summary>
        /// <param name="isPressed">if set to <c>true</c> [is pressed].</param>
        /// <returns></returns>
        public bool Invoke(bool isPressed)
        {
            bool isTaskPaneVisible = false;
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                if (ControllerInstance.CanPipelineAssociate(false))
                {
                    string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.AssociatePipeline);
                    if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
                    {
                        UserControl userControl =
                            ControllerInstance.UserControlCreator.GetUserControl(TaskPaneKey.AssociatePipeline);

                        ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);
                    }
                    else
                    {
                        AssociatePipelineTaskPane userControl = (AssociatePipelineTaskPane)
                            ControllerInstance.TaskPaneManager.GetTaskPaneUserControl(title);
                        userControl.SetDefaultValues();
                    }
                    ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
                    isTaskPaneVisible = true;
                }
            }
            return isTaskPaneVisible;
        }
    }
}
