using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    class PaneEditPipelineCommand : Command
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AssociatePipelineCommand"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        public PaneEditPipelineCommand(IController controller)
            : base(controller)
        {
        }

        /// <summary>
        /// Invokes the command assuming toggle button is pressed.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        public override void Invoke(string controlId)
        {
            Invoke(new PipelineAssociation());
        }

        /// <summary>
        /// Invokes this instance.
        /// </summary>
        /// <returns></returns>
        public void Invoke(PipelineAssociation pipelineAssociation)
        {
            if (ControllerInstance.CanPipelineAssociate(true))
            {
                string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.EditPipeline);
                if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
                {
                    UserControl userControl =
                        ControllerInstance.UserControlCreator.CreateEditUserControl(pipelineAssociation);

                    ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);
                }
                else
                {
                    AssociatePipelineTaskPane userControl = (AssociatePipelineTaskPane)
                        ControllerInstance.TaskPaneManager.GetTaskPaneUserControl(title);
                    userControl.EditExistingPipeline(pipelineAssociation);
                    userControl.SetDefaultValues();
                }
                ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, true);
            }
        }
    }
}
