using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;

namespace Microsoft.eResearch.GenePattern.Package
{
    class PaneInsertGenePatternLinkedCommand : Command
    {
         /// <summary>
        /// Initializes a new instance of the <see cref="AssociatePipelineCommand"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        public PaneInsertGenePatternLinkedCommand(IController controller)
            : base(controller)
        {
        }

        /// <summary>
        /// Invokes the command.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        public override void Invoke(string controlId)
        {
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                ControllerInstance.InsertGenePatternLinkImage(true,null);
            }
        }

        /// <summary>
        /// Invokes the specified is pressed.
        /// </summary>
        /// <param name="isPressed">if set to <c>true</c> [is pressed].</param>
        /// <returns></returns>
        public bool Invoke(bool isPressed)
        {
            bool isTaskPaneVisible = false;
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                if (ControllerInstance.CanPipelineAssociate(true))
                {
                    string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.InsertGenePatternLink);
                    if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
                    {
                        UserControl userControl =
                            ControllerInstance.UserControlCreator.GetUserControl(TaskPaneKey.InsertGenePatternLink);

                        ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);
                    }
                    else
                    {
                        AssociatePipelineTaskPane userControl = (AssociatePipelineTaskPane)
                            ControllerInstance.TaskPaneManager.GetTaskPaneUserControl(title);
                        userControl.SetDefaultValues();
                    }
                    ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
                    isTaskPaneVisible = true;
                }
            }
            return isTaskPaneVisible;
        }
    }
}
