using System.Windows.Forms;
namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// The command associated with the Associate PipelineName button of the 
    /// GenePattern tab in the Ribbon
    /// </summary>
    public class PaneRenurPipelineCommand : Command
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AssociatePipelineCommand"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        public PaneRenurPipelineCommand(IController controller)
            : base(controller)
        {
        }

        /// <summary>
        /// Invokes the command assuming toggle button is pressed.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        public override void Invoke(string controlId)
        {
            Invoke(true);
        }

        /// <summary>
        /// Invokes the specified is pressed.
        /// </summary>
        /// <param name="isPressed">if set to <c>true</c> [is pressed].</param>
        /// <returns></returns>
        public bool Invoke(bool isPressed)
        {
            bool isTaskPaneVisible = false;
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                if (ControllerInstance.CanPipelineRerun(false))
                {
                    string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.RerunPipeline);
                    if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
                    {
                        RerunPipelineTaskPane userControl =
                            (RerunPipelineTaskPane)ControllerInstance.UserControlCreator.GetUserControl(TaskPaneKey.RerunPipeline);
                        userControl.SetTheIndex(0);
                        ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);
                    }
                    RerunPipelineTaskPane rerunPipelineTaskPane = (RerunPipelineTaskPane)ControllerInstance.TaskPaneManager.GetTaskPaneUserControl(title, ControllerInstance.DocumentKey);
                    rerunPipelineTaskPane.SetTheIndex(0);
                    ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
                    isTaskPaneVisible = true;
                }
            }
            return isTaskPaneVisible;
        }

        /// <summary>
        /// Invokes the specified is pressed.
        /// </summary>
        /// <param name="isPressed">if set to <c>true</c> [is pressed].</param>
        /// <param name="selectedIndex">item to be selected</param>
        /// <returns></returns>
        public bool Invoke(bool isPressed, int selectedIndex)
        {
            bool isTaskPaneVisible = false;
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                if (ControllerInstance.CanPipelineRerun(false))
                {
                    string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.RerunPipeline);
                    if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
                    {
                        RerunPipelineTaskPane userControl =
                            (RerunPipelineTaskPane)ControllerInstance.UserControlCreator.GetUserControl(TaskPaneKey.RerunPipeline);
                        userControl.SetTheIndex(selectedIndex);
                        ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);
                    }
                    RerunPipelineTaskPane rerunPipelineTaskPane = (RerunPipelineTaskPane)ControllerInstance.TaskPaneManager.GetTaskPaneUserControl(title, ControllerInstance.DocumentKey);
                    rerunPipelineTaskPane.SetTheIndex(selectedIndex);
                    ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
                    isTaskPaneVisible = true;
                }
            }
            return isTaskPaneVisible;
        }
    }
}
