using System.Collections.Generic;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
   /// <summary>
   /// Command for the ViewAssociations toggle button
   /// </summary>
   public class ViewAssociationsCommand : Command
   {
      /// <summary>
      /// Initializes a new instance of the <see cref="ViewAssociationsCommand"/> class.
      /// </summary>
      /// <param name="controller">The controller.</param>
      public ViewAssociationsCommand(IController controller)
         : base(controller)
      {
      }

      /// <summary>
      /// Invokes the command assuming toggle button is pressed.
      /// </summary>
      /// <param name="controlId">The originating control id.</param>
      public override void Invoke(string controlId)
      {
         Invoke(true);
      }

      /// <summary>
      /// Invokes the command
      /// </summary>
      /// <param name="controlId">The originating control id.</param>
      /// <param name="isPressed">if set to <c>true</c> is toggle button is pressed.</param>
      public void Invoke(bool isPressed)
      {
         if (!ControllerInstance.ActiveDocumentIsNull)
         {
            string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.ViewAssociations);
            if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
            {
               UserControl userControl =
                   ControllerInstance.UserControlCreator.GetUserControl(TaskPaneKey.ViewAssociations);

               ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);

               AssociatedPipelinesUserControl associatedPipelinesUserControl =
                   userControl as AssociatedPipelinesUserControl;
               if (associatedPipelinesUserControl != null)
               {
                  List<PipelineAssociation> pipelineAssociationsList = ControllerInstance.GetAssociatedPipelinesForSelectedImage();
                  associatedPipelinesUserControl.DisplayPipelineAssociations(pipelineAssociationsList,
                      string.Empty, false);
               }
            }
            ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
            ControllerInstance.CheckFirstTimeRunning();
         }
      }

      /// <summary>
      /// Gets a value indicating whether the originating control needs to be invalidated.
      /// </summary>
      /// <value>
      /// 	<c>true</c> if the control needs to be invalidated; otherwise, <c>false</c>.
      /// </value>
      public override bool NeedsInvalidate
      {
         get
         {
            return true; // since the toggle action can get canceled, we need to requery always.
         }

      }

   }
}
