using System.Windows.Forms;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// Command for the ViewConnectionsCommand toggle button
    /// </summary>
    public class ViewConnectionsCommand : Command
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewConnectionsCommand"/> class.
        /// </summary>
        /// <param name="controller">The controller.</param>
        public ViewConnectionsCommand(IController controller) : base(controller)
        {
        }

        /// <summary>
        /// Invokes the command assuming toggle button is pressed.
        /// </summary>
        /// <param name="controlId">The originating control id.</param>
        public override void Invoke(string controlId)
        {
            Invoke(true);
        }

        /// <summary>
        /// Invokes the command
        /// </summary>
        /// <param name="isPressed">if set to <c>true</c> is toggle button is pressed.</param>
        public void Invoke(bool isPressed)
        {
            if (!ControllerInstance.ActiveDocumentIsNull)
            {
                string title = ControllerInstance.UserControlCreator.GetTitle(TaskPaneKey.Connections);
                if (!ControllerInstance.TaskPaneManager.TaskPaneExists(title))
                {
                    UserControl userControl =
                        ControllerInstance.UserControlCreator.GetUserControl(TaskPaneKey.Connections);

                    ControllerInstance.TaskPaneManager.CreateTaskPane(title, userControl);
                }
                ControllerInstance.CheckFirstTimeRunning();
                ControllerInstance.TaskPaneManager.SetTaskPaneVisibility(title, isPressed);
            }
        }

        /// <summary>
        /// Gets a value indicating whether the originating control needs to be invalidated.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if the control needs to be invalidated; otherwise, <c>false</c>.
        /// </value>
        public override bool NeedsInvalidate
        {
            get
            {
                return true; // since the toggle action can get canceled, we need to requery always.
            }
            
        }

    }
}
