using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// Download Pipeline Zip
    /// </summary>
    public partial class DownloadZipForm : Form
    {
        private IController _controller;
        private string _lsid;
        private string _fileName;
        private Thread _downloadThread;

        /// <summary>
        /// Initializes a new instance of the <see cref="DownloadZipForm"/> class.
        /// </summary>
        public DownloadZipForm()
        {
            InitializeComponent();
            this.BackgroundImage = Resources.Clean;
            this.BackgroundImageLayout = ImageLayout.Stretch;
        }

        /// <summary>
        /// Sets the work.
        /// </summary>
        /// <param name="controller">The controller.</param>
        /// <param name="lsid">The lsid.</param>
        /// <param name="filename">The filename.</param>
        public void SetWork(IController controller, string lsid, string filename)
        {
            this._controller = controller;
            this._lsid = lsid;
            this._fileName = filename;
        }

        /// <summary>
        /// Extracts the pipeline zip.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void ExtractPipelineZip()
        {
            // set text
            try
            {
                using (MemoryStream file = _controller.GetPipelineZip(_lsid, string.Empty))
                {
                    using (FileStream fileStream = new FileStream(_fileName, FileMode.Create))
                    {
                        using (BinaryWriter bw = new BinaryWriter(fileStream))
                        {
                            bw.Write(file.ToArray());
                        }
                    }
                }
            }
            catch (ThreadAbortException)
            {
            }
            catch (Exception e)
            {
                MessageForm.ShowUnhandledExceptionMessage(e);
                Trace.WriteLine("Exception in ExtractPipelineZip" + e.ToString());
            }
        }

        /// <summary>
        /// Handles the Shown event of the DownloadZipForm control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void DownloadZipForm_Shown(object sender, EventArgs e)
        {
            _downloadThread = new Thread(new ThreadStart(ExtractPipelineZip));
            _downloadThread.Start();
            timer1.Start();
        }

        /// <summary>
        /// Handles the Click event of the button1 control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void button1_Click(object sender, EventArgs e)
        {
            if (_downloadThread.IsAlive)
            {
                _downloadThread.Abort();
            }
            Close();
        }

        /// <summary>
        /// Handles the Tick event of the timer1 control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void timer1_Tick(object sender, EventArgs e)
        {
            if (!_downloadThread.IsAlive)
            {
                Close();
            }
        }
    }
}