using System;
using System.IO;
using Microsoft.eResearch.GenePattern.Common;
using Microsoft.eResearch.ScientificAddIn.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// Manages storage of files and models
    /// </summary>
    public interface IDataStore
    {
        /// <summary>
        /// Stores the file.
        /// </summary>
        /// <param name="file">The file.</param>
        /// <param name="lsid">The lsid.</param>
        /// <returns></returns>
        InternalFile StoreFile(Stream file, string lsid);

        /// <summary>
        /// Stores the file.
        /// </summary>
        /// <param name="file">The file.</param>
        /// <param name="lsid">The lsid.</param>
        /// <param name="documentKey">The document key.</param>
        /// <returns></returns>
        InternalFile StoreFile(Stream file, string lsid, string documentKey);

        /// <summary>
        /// Gets the hash key and store file.
        /// </summary>
        /// <param name="file">The file.</param>
        /// <param name="documentKey">The document key.</param>
        /// <returns></returns>
        InternalFile GetHashKeyAndStoreFile(Stream file, string documentKey);

        /// <summary>
        /// Gets the File GUID corresponding to the given Lsid .
        /// </summary>
        /// <param name="lsid">The lsid.</param>
        /// <returns>The GUID</returns>
        Guid GetFileGuid(string lsid);

        /// <summary>
        /// Determines whether the data storage contains the file with the specified lsid.
        /// </summary>
        /// <param name="lsid">The lsid.</param>
        /// <returns>
        /// 	<c>true</c> if the data storage contains the file for the given LSID; otherwise, <c>false</c>
        /// </returns>
        bool ContainsFile(string lsid);

        /// <summary>
        /// Get a previously stored file from its guid
        /// </summary>
        /// <param name="guid"></param>
        /// <returns></returns>
        MemoryStream GetFile(Guid guid);

        /// <summary>
        /// Gets the name of the file.
        /// </summary>
        /// <param name="guid">The GUID.</param>
        /// <param name="fileName">Name of the file. Send string.Empty to create temporary file</param>
        /// <param name="documentKey">The document key.</param>
        /// <returns></returns>
        string GetFileName(Guid guid, string fileName, string documentKey);

        /// <summary>
        /// Serializes the model.
        /// </summary>
        /// <param name="model">The model.</param>
        void SerializeModel(Model model);

        /// <summary>
        /// Deserializes the model.
        /// </summary>
        /// <returns></returns>
        Model DeserializeModel();

        /// <summary>
        /// Remove all data in the store that isn't being used by one of the passed lsids
        /// </summary>
        /// <param name="lsids"></param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists")]
        void Compress(System.Collections.Generic.List<string> lsids);

        /// <summary>
        /// Removes all content for this application
        /// </summary>
        void RemoveAllContent();

        /// <summary>
        /// Sets the package host for the datastore.  You must call this before using the object.
        /// </summary>
        /// <param name="host"></param>
        void SetPackageHost(IPackageHost host);
    }
}