using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// Creates UserControls.
    /// </summary>
    public interface IUserControlCreator
    {
        /// <summary>
        /// Gets a user control matching the specified <c>TaskPaneKey</c>.
        /// </summary>
        /// <param name="taskPaneKey">The task pane key.</param>
        /// <returns>a <c>UserControl</c> is there is a match otherwise null</returns>
        UserControl GetUserControl(TaskPaneKey taskPaneKey);

        /// <summary>
        /// Creates the edit user control.
        /// </summary>
        /// <param name="pipelineAssociation">The pipeline association.</param>
        /// <returns></returns>
        UserControl CreateEditUserControl(PipelineAssociation pipelineAssociation);

        /// <summary>
        /// Gets the title matching the specified <c>TaskPaneKey</c>.
        /// </summary>
        /// <param name="taskPaneKey">The task pane key.</param>
        /// <returns>a <c>string</c> with the matching title</returns>
        string GetTitle(TaskPaneKey taskPaneKey);

        /// <summary>
        /// Gets the task pane key.
        /// </summary>
        /// <param name="taskPaneTitleOrControlId">The task pane title.</param>
        /// <returns></returns>
        TaskPaneKey GetTaskPaneKey(string taskPaneTitleOrControlId);

        /// <summary>
        /// Gets the control id.
        /// </summary>
        /// <param name="taskPaneKey">The task pane key.</param>
        /// <returns></returns>
        string GetControlId(TaskPaneKey taskPaneKey);

        /// <summary>
        /// Gets the control id.
        /// </summary>
        /// <param name="controlKey">The control key.</param>
        /// <returns></returns>
        string GetControlId(ControlKey controlKey);
    }
}
