using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    internal class FromDocumentInstaller : PipelineInstaller
    {
        private IController controller;

        public FromDocumentInstaller(IController controller) : base(controller)
        {
            this.controller = controller;
        }

        protected override void InstallPipeline(IGenePatternServer destinationServer, string lsid)
        {
            try
            {
                using(MemoryStream stream = controller.GetPipelineZip(lsid, false))
                {
                    DoInstall(destinationServer, stream);
                }
            }
            catch (Exception ex)
            {
                string message = string.Format(CultureInfo.InvariantCulture, Resources.UNABLE_TO_INSTALL_PIPELINE, lsid);
                throw new PipelineOrModuleNotInstalledException(message, ex);
            }

        }

        protected override void InstallModule(IGenePatternServer destinationServer, string lsid)
        {
            try
            {
                Guid guid = controller.DataStore.GetFileGuid(lsid);

                using (MemoryStream stream = controller.DataStore.GetFile(guid))
                {
                    DoInstall(destinationServer, stream);
                }
            }
            catch (Exception ex)
            {
                string message = string.Format(CultureInfo.InvariantCulture, Resources.UNABLE_TO_INSTALL_MODULE, lsid);
                throw new PipelineOrModuleNotInstalledException(message, ex);
            }
        }

        private static void DoInstall(IGenePatternServer destinationServer, MemoryStream stream)
        {
            byte[] data = stream.ToArray();
            destinationServer.InstallPipeline(data);
            data = null;
        }
    }
}
