using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    internal class FromServerInstaller : PipelineInstaller
    {
        private IGenePatternServer sourceServer;

        public FromServerInstaller(IController controller, IGenePatternServer sourceServer)
            : base(controller)
        {
            this.sourceServer = sourceServer;
        }

        private void InstallPipelineOrModule(IGenePatternServer destinationServer, string lsid)
        {
            try
            {
                using (MemoryStream stream = sourceServer.DownloadTask(lsid, false))
                {
                    byte[] data = stream.ToArray();
                    destinationServer.InstallPipeline(data);
                    data = null;
                }
            }
            catch (Exception ex)
            {
                string message = string.Format(CultureInfo.InvariantCulture, Resources.UNABLE_TO_INSTALL_PIPELINE, lsid);
                throw new PipelineOrModuleNotInstalledException(message, ex);
            }
        }

        protected override void InstallPipeline(IGenePatternServer destinationServer, string lsid)
        {
            InstallPipelineOrModule(destinationServer, lsid);
        }

        protected override void InstallModule(IGenePatternServer destinationServer, string lsid)
        {
            InstallPipelineOrModule(destinationServer, lsid);
        }
    }
}
