using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using Microsoft.eResearch.GenePattern.Common;
using Ionic.Utils.Zip;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// Extracts and stores the files of a pipeline zip files (without modules embedded)
    /// </summary>
    public class PipelineZipExtractor
    {
        private IDataStore dataStore;

        /// <summary>
        /// Initializes a new instance of the <see cref="PipelineZipExtractor"/> class.
        /// </summary>
        /// <param name="dataStore">The data store.</param>
        public PipelineZipExtractor(IDataStore dataStore)
        {
            this.dataStore = dataStore;
        }

        /// <summary>
        /// Extracts and stores individual files and updates the Pipeline object.
        /// </summary>
        /// <param name="stream">The pipeline zip file stream.</param>
        /// <param name="documentKey">The document key.</param>
        /// <returns></returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists")]
        public List<InternalFile> GetFiles(Stream stream, string documentKey)
        {
            if (stream == null)
                throw new ArgumentNullException("stream");

            List<InternalFile> files = new List<InternalFile>();

            using (ZipFile zipFile = ZipFile.Read(stream))
            {
                foreach (ZipEntry zipEntry in zipFile)
                {
                    if (!zipEntry.IsDirectory)
                    {
                        InternalFile file = new InternalFile();
                        file.Filename = zipEntry.FileName;
                        file.LastModified = zipEntry.LastModified;

                        using (MemoryStream memoryStream = new MemoryStream())
                        {
                            zipEntry.Extract(memoryStream);

                            InternalFile storedFile = dataStore.GetHashKeyAndStoreFile(memoryStream, documentKey);
                            file.Lsid = storedFile.Lsid;
                            file.Guid = storedFile.Guid;
                            file.Length = memoryStream.Length;
                            files.Add(file);
                        }
                    }
                }
            }
            return files;
        }

    }
}
