using System;
using System.IO;
using System.Security.AccessControl;
using System.Security.Cryptography;
using System.Text;
using Microsoft.Win32;
using SecurityAlgo;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    internal sealed class DataCryptor
    {
        private SecurityKey securityKey;
        private readonly string REGISTRY_KEY_NAME = "GenePattern_Key";
        private readonly string REGISTRY_KEY_PATH; 
        private readonly string KEY_NAME = "KeyData";
        private readonly string IV_NAME = "IVData";


        internal DataCryptor()
        {
             REGISTRY_KEY_PATH = @"HKEY_CURRENT_USER\" + REGISTRY_KEY_NAME;
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Reliability", "CA2000:DisposeObjectsBeforeLosingScope")]
        internal void EncryptAndStoreData(MemoryStream sourceStream, Stream destination)
        {
            Rijndael rijndael = Rijndael.Create();
            InitializeAlgorithm(rijndael);
            ICryptoTransform cryptoTransform = rijndael.CreateEncryptor();
            BinaryReader input = new BinaryReader(sourceStream);
            using (CryptoStream encStream = new CryptoStream(destination, cryptoTransform, CryptoStreamMode.Write))
            {
                byte[] buffer = new byte[StreamHelper.BufferLength];
                int numBytes;
                while ((numBytes = input.Read(buffer, 0, StreamHelper.BufferLength)) > 0)
                    encStream.Write(buffer, 0, numBytes);

                buffer = null;
                encStream.FlushFinalBlock(); // MUST BE APPLIED!
            }
            
            input.Close();
            input = null;
        }

        internal MemoryStream GetDecryptedData(Stream encryptedStream)
        {
            byte[] bytes;
            Rijndael rijndael = Rijndael.Create();
            InitializeAlgorithm(rijndael);
            ICryptoTransform cryptoTransform = rijndael.CreateDecryptor();

            using (CryptoStream decStream = new CryptoStream(encryptedStream, cryptoTransform, CryptoStreamMode.Read))
            {
                using (StreamReader streamReader = new StreamReader(decStream))
                {
                    string data = streamReader.ReadToEnd();
                    ASCIIEncoding encoding = new ASCIIEncoding();
                    bytes = encoding.GetBytes(data);
                    data = null;
                }
            }
            
            MemoryStream decryptedStream = new MemoryStream(bytes);
            bytes = null;
            return decryptedStream;
        }

        private void InitializeAlgorithm(Rijndael et)
        {
            SecurityKey secureKey = this.GetKey();
            et.Key = ProtectedData.Unprotect(secureKey.Key, null, DataProtectionScope.CurrentUser);
            et.IV = ProtectedData.Unprotect(secureKey.IV, null, DataProtectionScope.CurrentUser);
        }
        public SecurityKey GetKey()
        {

            RegistryKey registryKey = Registry.CurrentUser;
            RegistryKey valKey = registryKey.OpenSubKey(REGISTRY_KEY_NAME);
            if (valKey != null)
            {
                securityKey = new SecurityKey();
                securityKey.Key = valKey.GetValue(KEY_NAME) as byte[];
                securityKey.IV = valKey.GetValue(IV_NAME) as byte[];
            }

            else
            {
                GenerateAndStoreSymmetricAESKey();
            }

            return securityKey;
        }

        private void GenerateAndStoreSymmetricAESKey()
        {
            securityKey = new SecurityKey();

            // The following call will create a Rijndael (AES) Crypto Provider with a cryptographically
            // random key and initialization vector. This crypto provider defaults to a key size
            // of 256 bits and considered extremely secure even by today's computing standards.

            Rijndael rij = Rijndael.Create();
            rij.GenerateKey();
            rij.GenerateIV();

            securityKey.Key = ProtectedData.Protect(
                                                        rij.Key,
                                                        null,
                                                        DataProtectionScope.CurrentUser);

            securityKey.IV = ProtectedData.Protect(
                                                        rij.IV,
                                                        null,
                                                        DataProtectionScope.CurrentUser);


            // Create a security context for a new key that we will use to store 
            // our shared key. The security context will restrict access to only 
            // our user.
            string user = Environment.UserDomainName + "\\" + Environment.UserName;
            RegistrySecurity security = new RegistrySecurity();
            RegistryAccessRule rule = new RegistryAccessRule(user,
                                                             RegistryRights.CreateSubKey | RegistryRights.WriteKey | RegistryRights.ReadKey,
                                                             InheritanceFlags.ContainerInherit,
                                                             PropagationFlags.None,
                                                             AccessControlType.Allow);
            security.AddAccessRule(rule);


            // Actually create the new registry key and apply the security context 
            // we just came up with.
            Registry.CurrentUser.CreateSubKey(REGISTRY_KEY_NAME, RegistryKeyPermissionCheck.ReadWriteSubTree, security);


            // Write the encrypted key into the registry
            Registry.SetValue(REGISTRY_KEY_PATH,KEY_NAME,securityKey.Key);

            // Write the encrypted IV into the registry
            Registry.SetValue(REGISTRY_KEY_PATH, IV_NAME, securityKey.IV);
        }

       
    }
}
