using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// User control for entering pipeline association annotation 
    /// and name
    /// </summary>
    public partial class AddAnnotation : AssociatePipelineWizardControl
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AddAnnotation"/> class.
        /// </summary>
        /// <param name="model">The model.</param>
        public AddAnnotation(AssociatePipelineWizardModel model)
            : base(model)
        {
            InitializeComponent();
        }
        /// <summary>
        /// Called when the control is hidden
        /// </summary>
        /// <returns>
        /// Returns false if the hide should be canceled
        /// </returns>
        public override bool OnHide(int delta)
        {
            // save annotation
            AssociatePipelineWizardModel.PipelineAssociation.Annotation = this.Annotation.Text.Trim();
            AssociatePipelineWizardModel.PipelineAssociation.Name = AssociationName.Text.Trim();
            return true;
        }

        /// <summary>
        /// Called when control is shown.
        /// </summary>
        public override void OnShown()
        {
            Annotation.Text = AssociatePipelineWizardModel.PipelineAssociation.Annotation;

            AssociationName.Text = AssociatePipelineWizardModel.PipelineAssociation.Name;
        }

        /// <summary>
        /// Returns true if the control can be hidden (advanced).  returns false
        /// if the control needs some correction or input.
        /// </summary>
        /// <returns></returns>
        public override bool CanHide()
        {
            return !string.IsNullOrEmpty(Annotation.Text.Trim()) && !string.IsNullOrEmpty(AssociationName.Text.Trim());
        }

        private void Annotation_TextChanged(object sender, EventArgs e)
        {
            AssociatePipelineWizardModel.PipelineAssociation.Annotation = Annotation.Text.Trim();
            UpdateNextButton();
        }

        private void AssociationName_TextChanged(object sender, EventArgs e)
        {
            AssociatePipelineWizardModel.PipelineAssociation.Name = AssociationName.Text.Trim();
            UpdateNextButton();
        }
    }
}
