using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace Infusion.GenePattern.Package
{
    public partial class AnnotationUserControl : UserControl
    {
        /// <summary>
        /// Occurs when [annotation text changed].
        /// </summary>
        public event EventHandler<EventArgs> AnnotationTextChanged;

        #region Public Methods

        /// <summary>
        /// Initializes a new instance of the <see cref="AnnotationUserControl"/> class.
        /// </summary>
        public AnnotationUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Gets the name of the association.
        /// </summary>
        /// <value>The name of the association.</value>
        public string AssociationName
        {
            get { return txtAssociationName.Text; }
        }

        /// <summary>
        /// Gets the annotation.
        /// </summary>
        /// <value>The annotation.</value>
        public string Annotation
        {
            get { return txtAnnotation.Text; }
        }

        /// <summary>
        /// Clears the annotation.
        /// </summary>
        public void ClearAnnotation()
        {
            txtAnnotation.Text = string.Empty;
            txtAssociationName.Text = string.Empty;
        }

        #endregion

        #region Private Method

        /// <summary>
        /// Called when [text changed].
        /// </summary>
        private void OnTextChanged()
        {
            if (AnnotationTextChanged != null)
            {
                AnnotationTextChanged(this, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Handles the TextChanged event of the txtAssociationName control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void txtAssociationName_TextChanged(object sender, EventArgs e)
        {
            OnTextChanged();
        }

        /// <summary>
        /// Handles the TextChanged event of the txtAnnotation control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void txtAnnotation_TextChanged(object sender, EventArgs e)
        {
            OnTextChanged();
        }

        #endregion
    }
}
