using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Timer=System.Timers.Timer;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class DownloadAnimationUserControl : UserControl
    {
        private Bitmap[] animationImages;
        private int currentImageIndex;
        private bool isUpload;
        private System.Timers.Timer timer = new Timer();

        /// <summary>
        /// Initializes a new instance of the <see cref="DownloadAnimationUserControl"/> class.
        /// </summary>
        public DownloadAnimationUserControl()
        {
            InitializeComponent();
            this.components = new System.ComponentModel.Container();
            components.Add(timer);
            animationImages = new Bitmap[]
                {
                    Resources.Animated_Download_Pipeline1,
                    Resources.Animated_Download_Pipeline2,
                    Resources.Animated_Download_Pipeline3,
                    Resources.Animated_Download_Pipeline4,
                    Resources.Animated_Download_Pipeline5,
                    Resources.Animated_Download_Pipeline6,
                    Resources.Animated_Download_Pipeline7
                };
            SetAnimationImage(0);
            timer.Interval = 150;
            timer.Elapsed += new System.Timers.ElapsedEventHandler(timer_Elapsed);
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is upload.
        /// </summary>
        /// <value><c>true</c> if this instance is upload; otherwise, <c>false</c>.</value>
        [Browsable(true)]
        [DefaultValue(false)]
        public bool IsUpload
        {
            get { return isUpload; }
            set { isUpload = value; }
        }

        private void SetAnimationImage(int index)
        {
            pictureBox1.Image = animationImages[index];
        }

        /// <summary>
        /// Switches the image.
        /// </summary>
        private void SwitchImage()
        {
            if (isUpload)
            {
                if (currentImageIndex < 0)
                    currentImageIndex = animationImages.Length - 1;
                SetAnimationImage(currentImageIndex);
                currentImageIndex--;
            }
            else
             {
                if (currentImageIndex > animationImages.Length - 1)
                    currentImageIndex = 0;
                SetAnimationImage(currentImageIndex);
                currentImageIndex++;                
            }
       }

       /// <summary>
       /// Elapseds this instance.
       /// </summary>
        public void Elapsed()
        {
            SwitchImage();
        }

        /// <summary>
        /// Starts this instance.
        /// </summary>
        public void Start()
        {
            timer.Start();
        }

        /// <summary>
        /// Stops this instance.
        /// </summary>
        public void Stop()
        {
            timer.Stop();
        }

        /// <summary>
        /// Handles the Elapsed event of the timer control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Timers.ElapsedEventArgs"/> instance containing the event data.</param>
        void timer_Elapsed(object sender, System.Timers.ElapsedEventArgs e)
        {
            this.Invoke(new MethodInvoker(Elapsed));
        }
    }
}
