using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class EditStopPoint : RerunPipelineWizardControl
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SelectStopPoint"/> class.
        /// </summary>
        /// <param name="model">The model.</param>
        public EditStopPoint(RerunPipelineWizardModel model)
            : base(model)
        {
            InitializeComponent();
            pipelineSteps.NodeMouseDoubleClick += new EventHandler<EventArgs>(pipelineSteps_NodeMouseDoubleClick);
        }

        /// <summary>
        /// Handles the NodeMouseDoubleClick event of the pipelineSteps control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void pipelineSteps_NodeMouseDoubleClick(object sender, EventArgs e)
        {
            try
            {
                PerformNextStep();
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        /// <summary>
        /// Called when control is shown.
        /// </summary>
        public override void OnShown()
        {
            Job job = RerunPipelineWizardModel.Job;
            if (!string.IsNullOrEmpty(job.PipelineLsid))
            {
                int stopPoint = job.StopPoint;
                Pipeline pipeline = RerunPipelineWizardModel.Pipelines[job.PipelineLsid];
                pipelineSteps.PipelineName = pipeline.Name;
                List<PipelineChild> stepNames = new List<PipelineChild>(pipeline.Steps.Count);
                for (int i = 0; i < pipeline.Steps.Count; i++)
                {
                    PipelineStep step = pipeline.Steps[i];
                    stepNames.Add(new PipelineChild(step.Name, (int)step.Type));
                }
                pipelineSteps.Children = stepNames.ToArray();
                pipelineSteps.SelectedChildIndex = stopPoint;
            }
            UpdateNextButton();
        }       

        /// <summary>
        /// Called when the control is hidden
        /// </summary>
        /// <returns>
        /// Returns false if the hide should be canceled
        /// </returns>
        public override bool OnHide(int delta)
        {
            RerunPipelineWizardModel.Job.StopPoint = pipelineSteps.SelectedChildIndex;
            return true;
        }

        /// <summary>
        /// Returns true if the control can be hidden (advanced).  returns false
        /// if the control needs some correction or input.
        /// </summary>
        /// <returns></returns>
        public override bool CanHide()
        {
            return pipelineSteps.SelectedChildIndex > -1;
        }

        private void EditStopPoint_Load(object sender, EventArgs e)
        {
            UpdateNextButton();
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void ResetButton_Click(object sender, EventArgs e)
        {
            try
            {
                RerunPipelineWizardModel.ResetStopPoint();
                Job job = RerunPipelineWizardModel.Job;
                if (job != null)
                    pipelineSteps.SelectedChildIndex = job.StopPoint;

            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }
    }
}
