using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// User control to show the introdocution 
    /// to creating or editing a pipeline association
    /// </summary>
    public partial class IntroPage : WizardBaseControl
    {
        private bool showIntroPage = true;
        private string header = "Header";

        /// <summary>
        /// Fires when the show intro check box changes value
        /// </summary>
        public event EventHandler<EventArgs> ShowIntroPageChanged;

        /// <summary>
        /// Initializes a new instance of the <see cref="IntroPage"/> class.
        /// </summary>
        public IntroPage()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Gets or sets a value indicating whether to show intro page.
        /// </summary>
        /// <value><c>true</c> if [show intro page]; otherwise, <c>false</c>.</value>
        [Browsable(true)]
        [DefaultValue(true)]
        [Description("The value of the checkbox where the user can select to hide or show the into page")]
        public bool ShowIntroPage
        {
            get { return showIntroPage; }
            set
            {
                showIntroPage = value;
                UpdateCall();
            }
        }

        private void UpdateCall()
        {
            showAgain.Checked = showIntroPage;
            headerLabel.Text = header;
        }

        /// <summary>
        /// Gets or sets the header.
        /// </summary>
        /// <value>The header.</value>
        [Browsable(true)]
        [DefaultValue("Header")]
        [Description("The value of the header text")]
        public string Header
        {
            get { return header; }
            set
            {
                header = value;
                UpdateCall();
            }
        }

        /// <summary>
        /// Called when show intro page changed. Raises the event
        /// </summary>
        protected void OnShowIntroPageChanged()
        {
            showIntroPage = showAgain.Checked;
            if(ShowIntroPageChanged != null)
            {
                ShowIntroPageChanged.Invoke(this, EventArgs.Empty);
            }
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void showAgain_CheckedChanged(object sender, EventArgs e)
        {
            try
            {
                OnShowIntroPageChanged();
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }
    }
}
