using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Infusion.GenePattern.Common;

namespace Infusion.GenePattern.Package
{
    public partial class PrimaryResultUserControl : UserControl
    {
        /// <summary>
        /// Excecution Log file Name
        /// </summary>
        public static readonly string EXECUTION_LOG = "execution_log.txt";

        #region Public Methods

        /// <summary>
        /// Initializes a new instance of the <see cref="PrimaryResultUserControl"/> class.
        /// </summary>
        public PrimaryResultUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Updates the primary result.
        /// </summary>
        /// <param name="selectedJob">The selected job.</param>
        /// <param name="pipeline">The pipeline.</param>
        public void UpdatePrimaryResult(Job selectedJob, Pipeline pipeline)
        {
            try
            {
                if (pipeline != null)
                {
                    pipelineSteps.PipelineName = pipeline.Name;
                    List<string> nameList = selectedJob.Filenames;
                    List<PipelineChild> resultNames = new List<PipelineChild>(nameList.Count);
                    int index = -1;
                    for (int i = 0; i < nameList.Count; i++)
                    {
                        if (!nameList[i].EndsWith(EXECUTION_LOG))
                        {
                            string r = nameList[i];
                            resultNames.Add(new PipelineChild(r, 0));
                            // TODO : look into what this codition means
                            //if (AssociatePipelineWizardModel.PipelineAssociation.PrimaryResultName == r)
                            {
                                index = resultNames.Count - 1;
                            }
                        }
                    }
                    pipelineSteps.Children = resultNames.ToArray();
                    pipelineSteps.SelectedChildIndex = index;
                }
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        /// <summary>
        /// Clears the primary result.
        /// </summary>
        internal void ClearPrimaryResult()
        {
            pipelineSteps.PipelineName = "";
            pipelineSteps.Children = null;
        }

        /// <summary>
        /// Gets the selected primary result.
        /// </summary>
        /// <param name="fileNames">The file names.</param>
        /// <returns></returns>
        public string GetSelectedPrimaryResult
        {
            get
            {
                if (pipelineSteps.SelectedChildIndex > -1)
                {
                    return pipelineSteps.Children[pipelineSteps.SelectedChildIndex].Name;
                }
                else
                {
                    return string.Empty;
                }
            }
        }

        /// <summary>
        /// Gets the index of the primary result selected.
        /// </summary>
        /// <value>The index of the primary result selected.</value>
        public int PrimaryResultSelectedIndex
        {
            get { return pipelineSteps.SelectedChildIndex; }
        }

        #endregion
    }
}
