using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class SelectPipelineAssociation : RerunPipelineWizardControl
    {        
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewPipelines"/> class.
        /// </summary>
        /// <param name="model">The model.</param>
        public SelectPipelineAssociation(RerunPipelineWizardModel model)
            : base(model as IWizardModel)
        {
            InitializeComponent();
            ShowPipelineAssociations();
        }

        /// <summary>
        /// Shows the pipeline associations.
        /// </summary>
        private void ShowPipelineAssociations()
        {
            RerunPipelineWizardModel rerunWizardModel = RerunPipelineWizardModel;

            Associations.Items.Clear();
            ListViewItem selecteditem = null;
            for (int index = 0; index < rerunWizardModel.PipelineAssociations.Count; index++)
            {
                PipelineAssociation pa = rerunWizardModel.PipelineAssociations[index];
                Pipeline p = rerunWizardModel.Pipelines[pa.PipelineLsid];
                ListViewItem item = new ListViewItem(pa.Name);
                item.SubItems.Add(p.Name);
                item.SubItems.Add(pa.Annotation);                
                item.ImageKey = p.IsLinked ? "linkedPipeline" : "pipeline";
                item.Tag = pa;
                if(rerunWizardModel.SelectedPipelineAssociation != null &&
                    pa.LocalId == rerunWizardModel.SelectedPipelineAssociation.LocalId)
                {
                    selecteditem = item;
                }
                Associations.Items.Add(item);
            }
            if(selecteditem != null)
            {
                selecteditem.Selected = true;
            }
            else if(Associations.Items.Count > 0)
            {
                Associations.Items[0].Selected = true;
            }
        }

        /// <summary>
        /// Returns true if the control can be hidden (advanced).  returns false
        /// if the control needs some correction or input.
        /// </summary>
        /// <returns></returns>
        public override bool CanHide()
        {
            return Associations.SelectedItems.Count > 0;
        }

        /// <summary>
        /// Called when the control is hidden
        /// </summary>
        /// <param name="delta"></param>
        /// <returns>
        /// Returns false if the hide should be canceled
        /// </returns>
        public override bool OnHide(int delta)
        {
            if(RerunPipelineWizardModel.SelectedPipelineAssociation == null)
                return true;

            if (delta >= 0 && RerunPipelineWizardModel.SelectedPipelineAssociation.Rerun.Job.Id > -1)
            {
              
            }
            return true;
        }

        /// <summary>
        /// Handles the SelectedIndexChanged event of the Associations control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void Associations_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (Associations.SelectedItems.Count > 0)
                {
                    PipelineAssociation pipelineAssociation = Associations.SelectedItems[0].Tag as PipelineAssociation;
                    RerunPipelineWizardModel.SelectedPipelineAssociation = pipelineAssociation;
                }
                UpdateNextButton();

            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        /// <summary>
        /// Handles the MouseDoubleClick event of the Associations control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Windows.Forms.MouseEventArgs"/> instance containing the event data.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void Associations_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            try
            {
                PerformNextStep();
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }
    }
}
