using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
   public partial class SelectStopPoint : AssociatePipelineWizardControl
   {
      /// <summary>
      /// Initializes a new instance of the <see cref="SelectStopPoint"/> class.
      /// </summary>
      /// <param name="model">The model.</param>
      public SelectStopPoint(AssociatePipelineWizardModel model)
         : base(model)
      {
         InitializeComponent();
         pipelineSteps.NodeMouseDoubleClick += new EventHandler<EventArgs>(pipelineSteps_NodeMouseDoubleClick);
      }

      /// <summary>
      /// Handles the NodeMouseDoubleClick event of the pipelineSteps control.
      /// </summary>
      /// <param name="sender">The source of the event.</param>
      /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
       [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
       private void pipelineSteps_NodeMouseDoubleClick(object sender, EventArgs e)
       {
           try
           {
               PerformNextStep();
           }
           catch (Exception ex)
           {
               MessageForm.ShowUnhandledExceptionMessage(ex);
           }
       }

      /// <summary>
      /// Called when control is shown.
      /// </summary>
      public override void OnShown()
      {
         Debug.Assert(AssociatePipelineWizardModel.PipelineAssociation.UserStopPoint >= 0, "Expected PipelineAssociation.UserStopPoint >= 0, was not");
         int stopPoint = AssociatePipelineWizardModel.PipelineAssociation.UserStopPoint;

         Pipeline pipeline = AssociatePipelineWizardModel.Pipeline;
         pipelineSteps.PipelineName = pipeline.Name;
         List<PipelineChild> stepNames = new List<PipelineChild>(pipeline.Steps.Count);
         for (int i = 0; i < pipeline.Steps.Count; i++)
         {
            PipelineStep step = pipeline.Steps[i];
            stepNames.Add(new PipelineChild(step.Name, (int)step.Type));
         }
         pipelineSteps.Children = stepNames.ToArray();
         pipelineSteps.SelectedChildIndex = stopPoint;

         UpdateNextButton();
      }

      /// <summary>
      /// Called when the control is hidden
      /// </summary>
      /// <returns>
      /// Returns false if the hide should be canceled
      /// </returns>
      public override bool OnHide(int delta)
      {
         AssociatePipelineWizardModel.PipelineAssociation.UserStopPoint = pipelineSteps.SelectedChildIndex;
         return true;
      }

      /// <summary>
      /// Returns true if the control can be hidden (advanced).  returns false
      /// if the control needs some correction or input.
      /// </summary>
      /// <returns></returns>
      public override bool CanHide()
      {
         return true;
      }

      /// <summary>
      /// Handles the Load event of the SelectStopPoint control.
      /// </summary>
      /// <param name="sender">The source of the event.</param>
      /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
      private void SelectStopPoint_Load(object sender, EventArgs e)
      {
         UpdateNextButton();
      }
   }
}
