using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Infusion.GenePattern.Common;

namespace Infusion.GenePattern.Package
{
    public partial class StopPointUserControl : UserControl
    {
        #region Public Method

        /// <summary>
        /// Initializes a new instance of the <see cref="StopPointUserControl"/> class.
        /// </summary>
        public StopPointUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Gets the select stop point.
        /// </summary>
        /// <value>The select stop point.</value>
        public int SelectedStopPoint
        {
            get { return pipelineSteps.SelectedChildIndex; }
        }

        /// <summary>
        /// Updates the stop point.
        /// </summary>
        /// <param name="pipelineAssociation">The pipeline association.</param>
        /// <param name="pipeline">The pipeline.</param>
        public void UpdateStopPoint(Pipeline pipeline)
        {
            try
            {
                if (pipeline != null)
                {
                    pipelineSteps.PipelineName = pipeline.Name;
                    List<PipelineChild> stepNames = new List<PipelineChild>(pipeline.Steps.Count);
                    
                    for (int i = 0; i < pipeline.Steps.Count; i++)
                    {
                        PipelineStep step = pipeline.Steps[i];
                        stepNames.Add(new PipelineChild(step.Name, (int)step.Type));
                    }
                    pipelineSteps.Children = stepNames.ToArray();
                    pipelineSteps.SelectedChildIndex = stepNames.Count - 1;
                }
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        /// <summary>
        /// Clears this instance.
        /// </summary>
        public void ClearStopPoint()
        {
            pipelineSteps.PipelineName = "";
            pipelineSteps.Children = null;
        }

        #endregion
    }
}
