using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Globalization;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// User control to show the introdocution 
    /// to creating or editing a pipeline association
    /// </summary>
    public partial class SummaryPage : RerunPipelineWizardControl
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="IntroPage"/> class.
        /// </summary>
        public SummaryPage(RerunPipelineWizardModel model)
            : base(model)
        {
            InitializeComponent();
        }

        /// <summary>
        /// Called when control is shown.
        /// </summary>
        public override void OnShown()
        {
            UpdateCall();
        }

        /// <summary>
        /// Updates the call.
        /// </summary>
        private void UpdateCall()
        {
            SummaryTextBox.Text = string.Empty;
            StringBuilder builder = new StringBuilder();

            BuildPipelineInfo(builder);
            BuildEmailInfo(builder);
            BuildServerSummaryInfo(builder);
            BuildVisualizerInfo(builder);

            SummaryTextBox.Text = builder.ToString();
        }

        /// <summary>
        /// Builds the pipeline info.
        /// </summary>
        /// <param name="builder">The builder.</param>
        private void BuildPipelineInfo(StringBuilder builder)
        {
            Pipeline pipeline = RerunPipelineWizardModel.SelectedPipeline;
            Job job = RerunPipelineWizardModel.Job;
            string selectedPipelineText = Resources.SELECTED_PIPELINE_SUMMARY_TEXT;
            builder.AppendFormat(CultureInfo.InvariantCulture, selectedPipelineText, pipeline.Name).AppendLine();

            if (pipeline.Parameters.Count > 0)
            {
                builder.AppendLine();
                string parametersText = Resources.PARAMETERS_SUMMARY_TEXT;
                builder.AppendLine(parametersText);
                foreach (PipelineParameter pipelineParameter in pipeline.Parameters)
                {
                    JobParameter jobParameter = job.GetParameter(pipelineParameter.Name);
                    string paramValue = string.Empty;
                    if (jobParameter != null && jobParameter.ParamValue != null)
                    {
                        if (pipelineParameter.Type == ParameterType.StringCollection)
                        {
                            paramValue = pipelineParameter.GetChoice(jobParameter.ParamValue.ToString()).Text;
                        }
                        else
                        {
                            paramValue = jobParameter.ParamValue.ToString();
                        }
                    }
                    builder.AppendFormat(CultureInfo.InvariantCulture, "{0} = {1}", pipelineParameter.ShortName, paramValue)
                        .AppendLine();
                }
            }

            builder.AppendLine();
            string stopAtText = Resources.STOP_AT_STEP_SUMMARY_TEXT;
            builder.AppendFormat(CultureInfo.InvariantCulture, stopAtText, job.StopPoint + 1,
                                 pipeline.Steps[job.StopPoint].Name).AppendLine();
        }

        /// <summary>
        /// Builds the email info.
        /// </summary>
        /// <param name="builder">The builder.</param>
        private void BuildEmailInfo(StringBuilder builder)
        {
            if (RerunPipelineWizardModel.DoEmailNotification)
            {
                builder.AppendLine();
                string sendNotificationText = Resources.SEND_NOTIFICATION_SUMMARY_TEXT;
                builder.AppendFormat(CultureInfo.InvariantCulture, sendNotificationText,
                                     RerunPipelineWizardModel.EmailAddress).AppendLine();
            }
            builder.AppendLine();
        }

        /// <summary>
        /// Builds the server summary info.
        /// </summary>
        /// <param name="builder">The builder.</param>
        private void BuildServerSummaryInfo(StringBuilder builder)
        {
            string runAtText = Resources.RUN_PIPELINE_ON_SERVER_SUMMARY_TEXT;
            builder.AppendFormat(CultureInfo.InvariantCulture, runAtText, RerunPipelineWizardModel.SelectedConnection.Name);
            builder.AppendLine();
            builder.AppendLine();
        }

        /// <summary>
        /// Builds the visualizer info.
        /// </summary>
        /// <param name="builder">The builder.</param>
        private void BuildVisualizerInfo(StringBuilder builder)
        {
            if (RerunPipelineWizardModel.SelectedPipeline.HasVisualizers)
            {
                string text = Resources.DO_SHOW_VISUALIZERS;
                if (!RerunPipelineWizardModel.ShowVisualizers)
                {
                    text = Resources.DONT_SHOW_VISUALIZERS;
                }
                builder.AppendLine(text);
            }
        }
    }
}
