using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class ViewPipelines : AssociatePipelineWizardControl
    {
        
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewPipelines"/> class.
        /// </summary>
        /// <param name="model">The model.</param>
        public ViewPipelines(AssociatePipelineWizardModel model)
            : base(model)
        {
            InitializeComponent();
        }


        /// <summary>
        /// Called when control is shown.
        /// </summary>
        public override void OnShown()
        {
            ShowPipelineAssociations();
        }

        /// <summary>
        /// Shows the pipeline associations.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1300:SpecifyMessageBoxOptions")]
        private void ShowPipelineAssociations()
        {
            Associations.Items.Clear();
            
            // Check whether the name given for this association already exist.
            if (!(associatePipelineWizard.IsEditing == true))
            {
                if (associatePipelineWizard.IsAssociationNameExist(null))
                {
                    MessageBox.Show("This document already contains an association with the same name", 
                        Resources.GENEPATTREN_MSG_HEADER, MessageBoxButtons.OK, MessageBoxIcon.Warning);
                    associatePipelineWizard.UpdateCall(-1);
                    return;
                }
            }      
            
            for (int index = 0; index < AssociatePipelineWizardModel.PipelineAssociations.Count; index++)
            {
                PipelineAssociation pa = AssociatePipelineWizardModel.PipelineAssociations[index];
                Pipeline p = AssociatePipelineWizardModel.Pipelines[index];
                ListViewItem item = new ListViewItem(pa.Name);
                item.SubItems.Add(p.Name);
                item.SubItems.Add(pa.Annotation);
                item.Tag = index;
                item.ImageKey = p.IsLinked ? "linkedPipeline" : "pipeline";
                Associations.Items.Add(item);
            }
            if (Associations.SelectedItems.Count == 0)
                this.RemoveAssociation.Enabled = false;
        }

        /// <summary>
        /// Shows the editing title.
        /// </summary>
        public void ShowEditingTitle()
        {
            this.titleLabel.Text = Resources.EDIT_ASSOCIATION;
            AddButton.Visible = false;
            RemoveAssociation.Visible = false;
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void AddButton_Click(object sender, EventArgs e)
        {
            try
            {
                Pipeline newPipeline = new Pipeline();
                AssociatePipelineWizardModel.Pipelines.Add(newPipeline);
                AssociatePipelineWizardModel.PipelineAssociations.Add(new PipelineAssociation());
                AssociatePipelineWizard wiz = this.Parent.Parent as AssociatePipelineWizard;
                if (wiz != null)
                {
                    wiz.AddAnotherPipeline();
                }
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1300:SpecifyMessageBoxOptions"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void RemoveAssociation_Click(object sender, EventArgs e)
        {
            try
            {
                if (Associations.SelectedItems.Count > 0)
                {
                    if (Associations.SelectedItems.Count - Associations.Items.Count == 0)
                    {
                        string message =
                            "Cannot delete all pipeline associations. Use the previous button to go back and edit it, or cancel to not add any associations.";
                        string title = "Deleting last pipeline association";
                        MessageBox.Show(message, title, MessageBoxButtons.OK, MessageBoxIcon.Information);
                    }
                    else
                    {
                        foreach (ListViewItem item in Associations.SelectedItems)
                        {
                            int index = (int)item.Tag;
                            AssociatePipelineWizardModel.Pipelines.Remove(AssociatePipelineWizardModel.Pipelines[index]);
                            AssociatePipelineWizardModel.PipelineAssociations.Remove(
                                AssociatePipelineWizardModel.PipelineAssociations[index]);
                        }
                    }
                    ShowPipelineAssociations();
                }
                UpdateNextButton();
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        private void Associations_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.RemoveAssociation.Enabled = Associations.SelectedItems.Count > 0 ? true : false;
        }
    }
}
