using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class WizardBaseControl : UserControl
    {
        /// <summary>
        /// The <c>AssociatePipelineWizardModel</c> with data for the 
        /// new or edited Pipeline Association(s)
        /// </summary>
        protected internal IWizardModel wizardModel;        
       
        /// <summary>
        /// for storing the reference to the wizard.
        /// </summary>
        protected internal AssociatePipelineWizard associatePipelineWizard;

        /// <summary>
        /// Initializes a new instance of the <see cref="WizardBaseControl"/> class.
        /// </summary>
        public WizardBaseControl()
        {
            wizardModel = new AssociatePipelineWizardModel();
            wizardModel.AddEmptyData();
            InitializeComponent();
        }


        /// <summary>
        /// Set the parent
        /// </summary>
        /// <param name="pipelineAssociationWizard">The pipeline association wizard.</param>
        public void SetParent(AssociatePipelineWizard pipelineAssociationWizard)
        {
            associatePipelineWizard = pipelineAssociationWizard;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="WizardBaseControl"/> class.
        /// </summary>
        /// <param name="model">The model.</param>
        protected internal WizardBaseControl(IWizardModel model)
        {
            wizardModel = model;
            InitializeComponent();
        }

        /// <summary>
        /// Returns true if the control can be hidden (advanced).  returns false
        /// if the control needs some correction or input.
        /// </summary>
        /// <returns></returns>
        public virtual bool CanHide()
        {
            return true;
        }

        /// <summary>
        /// Sets the model.
        /// </summary>
        /// <param name="model">The model.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1024:UsePropertiesWhereAppropriate")]
        public void SetModel(IWizardModel model)
        {
            wizardModel = model;
        }

        /// <summary>
        /// Called when control is shown.
        /// </summary>
        public virtual void OnShown()
        {
        }

        /// <summary>
        /// Called when the control is hidden
        /// </summary>
        /// <returns>Returns false if the hide should be canceled</returns>
        public virtual bool OnHide(int delta)
        {
            return true;
        }

        /// <summary>
        /// Updates the next button.
        /// </summary>
        protected virtual void UpdateNextButton()
        {
            IWizard wizard = Parent.Parent as IWizard;
            if (wizard != null)
            {
                wizard.EnableNextButton(CanHide());
                wizard.UpdateFinishButton();
            }
        }

        /// <summary>
        /// Performs the next step.
        /// </summary>
        protected virtual void PerformNextStep()
        {
              IWizard wizard = Parent.Parent as IWizard;
              if (wizard != null)
              {
                  wizard.PerformNextStep();
              }
        }
    }
}
