using System;
using System.Diagnostics;
using System.IO;
using System.Xml.Serialization;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    internal class UserDataManager
    {
        private const string userdataFilename = @"\UserData.xml";
        private const string folder = @"\Infusion Development\GenePatternPackage\";
        private static DataCryptor cryptor = new DataCryptor();

        private UserDataManager()
        { }

        public static UserData Read()
        {
            UserData userData;

            string path = Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData);
            path += folder;
            path += userdataFilename;

            if (File.Exists(path))
            {

                using (FileStream destinationStream = File.OpenRead(path))
                {
                    using (MemoryStream connectionStream = cryptor.GetDecryptedData(destinationStream))
                    {
                        XmlSerializer serializer = new XmlSerializer(typeof(UserData));
                        userData = serializer.Deserialize(connectionStream) as UserData;
                    }
                }

            }
            else
            {
                userData = new UserData();
            }

            return userData;
        }

        public static void Save(UserData userData)
        {
            if (userData == null)
                throw new ArgumentNullException("userData");

            string path = GetPath();
            if (!Directory.Exists(path))
            {
                Directory.CreateDirectory(path);
            }

            string temporaryFilePath = path;   //Application folder path as destination folder for moving tmp files
            path += userdataFilename;
            Random r = new Random();
            int rand = r.Next(99999);
            temporaryFilePath += @"\userdatabkup" + rand + ".tmp";
            // backup the old user data to a temp filename in case something blows up
            if (File.Exists(path))
            {
                if (File.Exists(temporaryFilePath))
                {
                    File.Delete(temporaryFilePath);
                }

                File.Move(path, temporaryFilePath);
            }

            try
            {
                XmlSerializer serializer = new XmlSerializer(typeof(UserData));
                using (MemoryStream connectionStream = new MemoryStream())
                {
                    serializer.Serialize(connectionStream, userData);
                    connectionStream.Position = 0;

                    using (FileStream destinationStream = new FileStream(path, FileMode.CreateNew))
                    {
                        cryptor.EncryptAndStoreData(connectionStream, destinationStream);
                        Trace.WriteLine("Saved user data", TraceLevel.Info.ToString());
                    }
                }
            }
            catch (Exception e)
            {
                Trace.WriteLine("Exception: " + e, TraceLevel.Error.ToString());

                // restore in the event of an exception
                if (File.Exists(path))
                {
                    File.Delete(path);
                }

                if (File.Exists(temporaryFilePath))
                {
                    File.Move(temporaryFilePath, path);
                }
                throw;
            }

            if (File.Exists(temporaryFilePath))
            {
                File.Delete(temporaryFilePath);
            }
        }

        private static string GetPath()
        {
            string path = Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData);
            path += folder;
            return path;
        }

        public static string GetTempPath(string localFolder)
        {
            return GetPath() + @"Temp\" + localFolder;
        }
    }
}
