using System.Collections.Generic;

namespace Microsoft.eResearch.GenePattern.Package
{
    /// <summary>
    /// Class to indicate validation result and possible validation error messages
    /// </summary>
    internal class ValidationResult
    {
        private bool isValid;
        private readonly List<string> messages = new List<string>();

        /// <summary>
        /// Initializes a new instance of the <see cref="ValidationResult"/> class.
        /// </summary>
        public ValidationResult()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ValidationResult"/> class.
        /// </summary>
        /// <param name="isValid">if set to <c>true</c> [is valid].</param>
        public ValidationResult(bool isValid)
        {
            this.isValid = isValid;
        }

        /// <summary>
        /// Gets a value indicating whether validation subject is valid or not.
        /// </summary>
        /// <value><c>true</c> if this subject is valid; otherwise, <c>false</c>.</value>
        public bool IsValid
        {
            get { return isValid; }
        }

        /// <summary>
        /// Gets the messages.
        /// </summary>
        /// <value>The messages.</value>
        public IList<string> Messages
        {
            get { return messages; }
        }

        /// <summary>
        /// Merges the specified validation result. 
        /// </summary>
        /// <param name="validationResult">The validation result to merge into the the current instance.</param>
        internal void Merge(ValidationResult validationResult)
        {
            if(!validationResult.isValid)
            {
                isValid = false;
            }

            foreach (string message in validationResult.messages)
            {
                messages.Add(message);
            }
        }

        /// <summary>
        /// Gets the messages concatenated to one string instance.
        /// </summary>
        /// <returns>the <c>that is the concatenation of all messages separated by new 
        /// line and return (\n\r)</c></returns>
        internal string GetMessage()
        {
            string[] array = new string[messages.Count];
            messages.CopyTo(array, 0);

            return string.Join("\n\r", array);

        }
    }
}
