using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;
using System.Globalization;
using Microsoft.eResearch.ScientificAddIn.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class SelectPipelineToRerunUserControl : UserControl
    {
        private ICollection<PipelineAssociation> _documentSearchResult;
        private IController _controller;
        string _documentKey = string.Empty;

        /// <summary>
        /// Occurs when [jobs selected index changed].
        /// </summary>
        public event EventHandler<EventArgs> AssociationSelectedIndexChanged;

        /// <summary>
        /// Occurs when Association is empty.
        /// </summary>
        public event EventHandler<EventArgs> AssociationCleared;

        /// <summary>
        /// Initializes a new instance of the <see cref="SelectPipelineToRerunUserControl"/> class.
        /// </summary>
        public SelectPipelineToRerunUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Lists the jobs from document.
        /// </summary>
        private void ListJobsFromDocument(DocumentImage selectedImage)
        {
            Association.Items.Clear();
            _documentSearchResult = new List<PipelineAssociation>();

            foreach (PipelineAssociation pa in _controller.GetAssociatedPipelinesForSelectedImage(selectedImage, _documentKey))
            {

                ListViewItem newItem = Association.Items.Add(pa.Name.ToString(CultureInfo.InvariantCulture));
                newItem.ImageKey = "job";
                // if jobs are coming from the document, get name of association
                // go through existing associations and find 
                newItem.SubItems.Add(pa.Job.PipelineName);
                newItem.SubItems.Add(pa.Name);
                newItem.Tag = pa;
            }
        }

        /// <summary>
        /// Intials the update.
        /// </summary>
        /// <param name="controller">The controller.</param>
        /// <param name="documentKey">The document key.</param>
        /// <param name="selectedImage">The selected image.</param>
        internal void IntialUpdate(IController controller, string documentKey, DocumentImage selectedImage)
        {
            _controller = controller;
            _documentKey = documentKey;
            ListJobsFromDocument(selectedImage);
        }

        /// <summary>
        /// Handles the SelectedIndexChanged event of the Association control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void Association_SelectedIndexChanged(object sender, EventArgs e)
        {
            OnJobsSelectedIndexChanged();
        }

        /// <summary>
        /// Called when [jobs selected index changed].
        /// </summary>
        private void OnJobsSelectedIndexChanged()
        {
            if (AssociationSelectedIndexChanged != null)
            {
                AssociationSelectedIndexChanged(this, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Gets the pipeline.
        /// </summary>
        /// <param name="pipelineLsid">The pipeline lsid.</param>
        /// <param name="documentKey">The document key.</param>
        /// <returns></returns>
        public Pipeline GetPipeline(string pipelineLsid, string documentKey)
        {
            return _controller.GetDocumentModel(documentKey).Pipelines[pipelineLsid].Clone() as Pipeline;
        }

        /// <summary>
        /// Gets the PipelineAssociation
        /// </summary>
        /// <returns></returns>
        internal PipelineAssociation GetPipelineAssociation()
        {
            if (Association.SelectedItems.Count > 0)
            {
                return Association.SelectedItems[0].Tag as PipelineAssociation;
            }
            return null;
        }

        /// <summary>
        /// Lists the job from document.
        /// </summary>
        /// <param name="pipelineAssociationsList">The pipeline associations list.</param>
        /// <param name="DocumentKey">The document key.</param>
        internal void ListJobFromDocument(List<PipelineAssociation> pipelineAssociationsList, string DocumentKey)
        {
            Association.Items.Clear();
            AssociationCleared(this, EventArgs.Empty);
            Model currentModel = null;
            if (string.IsNullOrEmpty(DocumentKey))
                currentModel = _controller.ActiveModel;
            else
                currentModel = _controller.GetDocumentModel(DocumentKey);

            foreach (PipelineAssociation association in pipelineAssociationsList)
            {
                Pipeline pipeline = currentModel.Pipelines[association.PipelineLsid];

                ListViewItem item = Association.Items.Add(association.Name.ToString(CultureInfo.InvariantCulture));
                item.Text = association.Name;
                item.ImageKey = "job";
                item.SubItems.Add(pipeline.Name);
                item.SubItems.Add(association.Name);
                item.Tag = association;
            }
            if (Association.Items.Count > 0)
            {
                Association.Items[0].Selected = true;
            }
        }

        /// <summary>
        /// Sets the index.
        /// </summary>
        /// <param name="index">The index.</param>
        internal void SetIndex(int index)
        {
            if (Association.Items.Count > 0)
            {
                Association.Items[index].Selected = true;
                Association.Select();
            }
        }
    }
}
