using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;
using System.Xml;
using System.IO;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class ServeSettingUserControl : UserControl
    {
        private const string NEW_CONNECTION_PROMPT = "New Connection ...";
        private const string GENEPATTERN_PUBLIC_SERVER = "GenePattern Public Server ...";
        private const string EMPTY_CONNECTION_PROMPT = "Select Connection ....";
        private string GenePatternServerName = "";
        private IController controller;

        /// <summary>
        /// Event Hanlder Set Rerun Button
        /// </summary>
        public EventHandler<EventArgs> SetRerunButton;

        /// <summary>
        /// Initializes a new instance of the <see cref="ServeSettingUserControl"/> class.
        /// </summary>
        public ServeSettingUserControl()
        {
            InitializeComponent();
            GetDefaultGenePatternServerName();
        }

        /// <summary>
        /// Adds the connection to combo box.
        /// </summary>
        private void AddConnectionToComboBox()
        {
            InitializeComboBoxes();
            int index = 3; //as empty connection Prompt is 0, new connection prompt is 1
            int selectedIndex = 0;
            bool containsGenePatternServerConnection = false;
            Connection currentConnection = this.controller.CurrentConnection;

            foreach (KeyValuePair<string, Connection> connectionMapping in this.controller.UserData.Connections)
            {
                Connection connection = connectionMapping.Value;
                serverConnectionscomboBox.Items.Add(connection);

                if (connection.Equals(currentConnection))
                {
                    selectedIndex = index;
                }
                
                if (!containsGenePatternServerConnection)
                {
                    if (string.Compare(connection.ServerName, GenePatternServerName, true) == 0)
                    {
                        containsGenePatternServerConnection = true;
                    }
                }

                index++;
            }

            if (containsGenePatternServerConnection)
            {
                serverConnectionscomboBox.Items.RemoveAt(2);
                selectedIndex--;
            }

            if (serverConnectionscomboBox.Items.Count > 0)
            {
                serverConnectionscomboBox.SelectedIndex = selectedIndex;
                serverConnectionscomboBox_SelectedIndexChanged(this.serverConnectionscomboBox, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Initializes the combo boxes.
        /// </summary>
        private void InitializeComboBoxes()
        {
            this.serverConnectionscomboBox.Items.Clear();
            this.serverConnectionscomboBox.Items.Add(EMPTY_CONNECTION_PROMPT);
            this.serverConnectionscomboBox.Items.Add(NEW_CONNECTION_PROMPT);
            this.serverConnectionscomboBox.Items.Add(GENEPATTERN_PUBLIC_SERVER);
        }

        /// <summary>
        /// Handles the CheckedChanged event of the emailCheckBox control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void emailCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (this.emailCheckBox.Checked)
            {
                emailAddress.Enabled = true;
            }
            else if (!this.emailCheckBox.Checked)
            {
                emailAddress.Enabled = false;
                emailAddress.Text = string.Empty;
            }
        }

        /// <summary>
        /// Handles the SelectedIndexChanged event of the serverConnectionscomboBox control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        private void serverConnectionscomboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {

                ComboBox comboBox = sender as ComboBox;

                object selectedValue = comboBox.SelectedItem;
                if (!selectedValue.Equals(NEW_CONNECTION_PROMPT) &&
                    !selectedValue.Equals(EMPTY_CONNECTION_PROMPT) &&
                            !selectedValue.Equals(GENEPATTERN_PUBLIC_SERVER))
                {
                    Connection connection = comboBox.SelectedItem as Connection;
                    if (connection != null)
                    {
                        SetRerunButton(true, EventArgs.Empty);
                    }
                    else
                    {
                        SetRerunButton(false, EventArgs.Empty);
                    }
                }
                else if (selectedValue.Equals(NEW_CONNECTION_PROMPT))
                {
                    if (this.controller != null)
                    {
                        this.controller.ShowServerConnectionForm(null, false);
                    }
                    RemoveIndexChangedEventHandler();
                    this.AddConnectionToComboBox();
                    AddIndexChangedEventHandler();
                }
                else if (selectedValue.Equals(GENEPATTERN_PUBLIC_SERVER))
                {
                    this.controller.ShowGenePatternServerConnectionForm(null, false);
                    RemoveIndexChangedEventHandler();
                    this.AddConnectionToComboBox();
                    AddIndexChangedEventHandler();
                    SetRerunButton(true, EventArgs.Empty);
                }
                else if (selectedValue.Equals(EMPTY_CONNECTION_PROMPT))
                {
                    SetRerunButton(false, EventArgs.Empty);
                }


            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        /// <summary>
        /// Adds the index changed event handler.
        /// </summary>
        private void AddIndexChangedEventHandler()
        {
            serverConnectionscomboBox.SelectedIndexChanged += new EventHandler(serverConnectionscomboBox_SelectedIndexChanged);
        }

        /// <summary>
        /// Removes the index changed event handler.
        /// </summary>
        private void RemoveIndexChangedEventHandler()
        {
            serverConnectionscomboBox.SelectedIndexChanged -= new EventHandler(serverConnectionscomboBox_SelectedIndexChanged);
        }

        /// <summary>
        /// Sets the controll.
        /// </summary>
        /// <param name="_controller">The _controller.</param>
        internal void SetControll(IController _controller)
        {
            this.controller = _controller;
            AddConnectionToComboBox();

        }

        /// <summary>
        /// Gets the connection.
        /// </summary>
        /// <returns></returns>
        public Connection GetConnection
        {
            get
            {
                Connection connection = serverConnectionscomboBox.SelectedItem as Connection;
                if (connection != null)
                {
                    SetRerunButton(true, EventArgs.Empty);
                    return (connection.Clone() as Connection);
                }
                else
                {
                    SetRerunButton(false, EventArgs.Empty);
                    return null;
                }
            }
        }

        /// <summary>
        /// Does the email notification.
        /// </summary>
        /// <returns></returns>
        internal bool DoEmailNotification()
        {
            return (emailCheckBox.Checked);
        }

        /// <summary>
        /// Gets the email address.
        /// </summary>
        /// <returns></returns>
        internal string GetEmailAddress()
        {
            return (emailAddress.Text);
        }

        /// <summary>
        /// Shows the visualizers.
        /// </summary>
        /// <returns></returns>
        internal bool ShowVisualizers()
        {
            return (showResultsCheckBox.Checked);
        }

        /// <summary>
        /// Updates the connections combo box.
        /// </summary>
        internal void UpdateConnectionsComboBox()
        {
            RemoveIndexChangedEventHandler();
            AddConnectionToComboBox();
            AddIndexChangedEventHandler();
        }

        /// <summary>
        /// Sets the show result.
        /// </summary>
        /// <param name="p">if set to <c>true</c> [p].</param>
        internal void SetShowResult(bool p)
        {
            showResultsCheckBox.Checked = p;
            showResultsCheckBox.Enabled = p;
        }

        /// <summary>
        /// Gets the default name of the gene pattern server.
        /// </summary>
        private void GetDefaultGenePatternServerName()
        {
            try
            {
                string filePath = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
                            "Infusion Development\\GenePattern Reproducible Research Document Add-In");
                bool isFileExists = File.Exists(Path.Combine(filePath, "GenePatternPublicServer.xml"));
                if (isFileExists)
                {
                    filePath = Path.Combine(filePath, "GenePatternPublicServer.xml");
                    XmlDocument genePattenPublicServer = new XmlDocument();
                    genePattenPublicServer.Load(filePath);
                    XmlNodeList nodelist = genePattenPublicServer.SelectNodes("//appsettings/add");
                    foreach (XmlNode xnode in nodelist)
                    {
                        if (xnode.Attributes["Name"].Value == "ServerName")
                        {
                            GenePatternServerName = xnode.Attributes["value"].Value;
                            break;
                        }
                    }
                }
                else
                {
                    GenePatternServerName = "GenePattern.Broad.MIT.edu";
                }
            }
            catch (Exception)
            {
                GenePatternServerName = "GenePattern.Broad.MIT.edu";
            }
        }

    }
}
