using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.eResearch.GenePattern.Common;

namespace Microsoft.eResearch.GenePattern.Package
{
    public partial class StopPointUserControl : UserControl
    {
        #region Public Method

        /// <summary>
        /// Initializes a new instance of the <see cref="StopPointUserControl"/> class.
        /// </summary>
        public StopPointUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Gets the select stop point.
        /// </summary>
        /// <value>The select stop point.</value>
        public int SelectedStopPoint
        {
            get { return pipelineSteps.SelectedChildIndex; }
            set 
            {
                if (value != -1 && value < pipelineSteps.Children.Length)
                {
                    pipelineSteps.SelectedChildIndex = value;
                }
            }
        }

        /// <summary>
        /// Gets the name of the selected stop point.
        /// </summary>
        /// <value>The name of the selected stop point.</value>
        public string SelectedStopPointName
        {
            get
            { 
                if(pipelineSteps.SelectedChildIndex != -1 && pipelineSteps.Children.Length <= pipelineSteps.SelectedChildIndex)
                    return pipelineSteps.Children[pipelineSteps.SelectedChildIndex].Name;

                return string.Empty;
            }
        }

        /// <summary>
        /// Updates the stop point.
        /// </summary>
        /// <param name="pipeline">The pipeline.</param>
        /// <param name="stopPoint">The stop point.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")]
        public void UpdateStopPoint(Pipeline pipeline, int stopPoint)
        {
            try
            {
                if (pipeline != null)
                {
                    pipelineSteps.PipelineName = pipeline.Name;
                    List<PipelineChild> stepNames = new List<PipelineChild>(pipeline.Steps.Count);

                    for (int i = 0; i < pipeline.Steps.Count; i++)
                    {
                        PipelineStep step = pipeline.Steps[i];
                        stepNames.Add(new PipelineChild(step.Name, (int)step.Type));
                    }
                    pipelineSteps.Children = stepNames.ToArray();
                    pipelineSteps.SelectedChildIndex = stopPoint;
                }
            }
            catch (Exception ex)
            {
                MessageForm.ShowUnhandledExceptionMessage(ex);
            }
        }

        /// <summary>
        /// Clears this instance.
        /// </summary>
        public void ClearStopPoint()
        {
            pipelineSteps.PipelineName = "";
            pipelineSteps.Children = null;
        }

        #endregion
    }
}
