using System;
using System.Collections.Generic;
using System.Net;
using System.Text;

namespace Microsoft.eResearch.GenePattern.Server
{
    /// <summary>
    /// Helper class for configuring http headers for authentication
    /// </summary>
    public sealed class AuthorizationHelper
    {
        private AuthorizationHelper()
        {
            
        }

        /// <summary>
        /// Sets the up authorization.
        /// </summary>
        /// <param name="request">The request.</param>
        /// <param name="preAuthenticate">if set to <c>true</c> pre authenticate.</param>
        /// <param name="credentials">The credentials.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2201:DoNotRaiseReservedExceptionTypes")]
        public static void SetUpAuthorization(WebRequest request, bool preAuthenticate, NetworkCredential credentials)
        {
            if (request == null)
                throw new ArgumentNullException("request");

            if (preAuthenticate)
            {
                if (credentials != null)
                {
                    string credentialString = credentials.UserName + ":" +
                                              credentials.Password;

                    byte[] credentialBuffer = new UTF8Encoding().GetBytes(credentialString);

                    request.Headers["Authorization"] =
                        "Basic " + Convert.ToBase64String(credentialBuffer);
                    request.Headers["Credentials"] = credentialString;
                }
                else
                {
                    throw new ApplicationException(Resource1.NO_NETWORK_CENDENTIALS);
                }
            }
        }

    }
}
