
using System.Collections.Generic;
using System.IO;
using System.Text;

namespace Microsoft.eResearch.GenePattern.Server
{
    /// <summary>
    /// A version of a binary reader than can also perform the ReadLine() functionality from streamReader, without buffering the input stream.
    /// </summary>
    class BinaryAndStringReader : BinaryReader
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="BinaryAndStringReader"/> class.
        /// </summary>
        /// <param name="stream">The stream.</param>
        public BinaryAndStringReader(Stream stream) : base(stream)
        {
        }

        
        /// <summary>
        /// Reads the line.
        /// </summary>
        /// <returns></returns>
        public string ReadLine()
        {
            // returns null when you reach the end of the stream
            if(BaseStream.Position ==  BaseStream.Length)
            {
                return null;
            }

            StringBuilder result = new StringBuilder();
            char c;
            do
            {
                c = (char) ReadByte();
                if (c != '\r' && c != '\n')
                {
                    result.Append(c);
                }
                else
                {
                    // hit the end the line, but if next char is \n and current char is \r, read it also since line ends 
                    // can have 2 chars
                    if(c == '\r' && PeekChar() == '\n')
                    {
                        ReadByte();
                    }
                }
            } while (c != '\r' && c != '\n' && BaseStream.Position !=  BaseStream.Length);
            return result.ToString();
        }
    }
}
