using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Xml;

namespace Infusion.GenePattern.Server
{
    public class XmlTextReaderHelper
    {
        private const string _dataHandlerName = "DataHandler";
        private const string _filterDataHandlerFilePath = @"..\..\filteredDataHandler.tmp";
        private const string _xmlDomResultFilePath = @"..\..\xmlDomResult.tmp";
        private const string _mergeResultFilePath = @"..\..\mergeResult.tmp";

        /// <summary>
        /// Removes the data handler.
        /// </summary>
        public static FileStream RemoveDataHandlerContents(Stream inputStream)
        {
            bool found = false;
            inputStream.Position = 0;

            if (File.Exists(_filterDataHandlerFilePath))
            {
                File.Delete(_filterDataHandlerFilePath);
            }

            //FileStream to store Xml Content without Data i.e. DataContent is replaced with "1" to reduce the File Size
            using (FileStream fs = new FileStream(_filterDataHandlerFilePath, FileMode.Create, FileAccess.Write))
            {
                XmlTextWriter xmlTextWriter = new XmlTextWriter(fs, Encoding.ASCII);
                xmlTextWriter.Formatting = Formatting.Indented;

                XmlTextReader xmlTextReader = new XmlTextReader(inputStream);

                #region Write Content without data to File

                while (xmlTextReader.Read())
                {

                    switch (xmlTextReader.NodeType)
                    {
                        case XmlNodeType.Element:

                            if (xmlTextReader.Name.Contains(_dataHandlerName))
                                found = true;

                            xmlTextWriter.WriteStartElement(xmlTextReader.Prefix, xmlTextReader.LocalName, xmlTextReader.NamespaceURI);
                            xmlTextWriter.WriteAttributes(xmlTextReader, true);

                            if (xmlTextReader.IsEmptyElement)
                                xmlTextWriter.WriteEndElement();
                            break;

                        case XmlNodeType.Text:
                            if (found)
                                xmlTextWriter.WriteString("1");
                            else
                                xmlTextWriter.WriteString(xmlTextReader.Value);
                            break;

                        case XmlNodeType.Whitespace:
                        case XmlNodeType.SignificantWhitespace:
                            xmlTextWriter.WriteWhitespace(xmlTextReader.Value);
                            break;

                        case XmlNodeType.CDATA:
                            xmlTextWriter.WriteCData(xmlTextReader.Value);
                            break;

                        case XmlNodeType.EntityReference:
                            xmlTextWriter.WriteEntityRef(xmlTextReader.Name);
                            break;

                        case XmlNodeType.XmlDeclaration:
                        case XmlNodeType.ProcessingInstruction:
                            xmlTextWriter.WriteProcessingInstruction(xmlTextReader.Name, xmlTextReader.Value);
                            break;

                        case XmlNodeType.Comment:
                            xmlTextWriter.WriteComment(xmlTextReader.Value);
                            break;

                        case XmlNodeType.EndElement:
                            if (xmlTextReader.Name.Contains(_dataHandlerName))
                                found = false;
                            xmlTextWriter.WriteFullEndElement();
                            break;

                    }

                }
                #endregion

                #region Release Resources

                fs.Flush();
                xmlTextWriter.Flush();
                xmlTextWriter.Close();
                fs.Close();
                xmlTextReader = null;
                xmlTextWriter = null;
                GC.Collect();

                #endregion
            }
            return new FileStream(_filterDataHandlerFilePath, FileMode.Open, FileAccess.Read);
        }

        /// <summary>
        /// Merges the stream.
        /// </summary>
        /// <param name="oldStream">The old stream.</param>
        public static MemoryStream MergeDataHandlerContentInResultFile(Stream oldStream)
        {
            bool found = false;

            if (File.Exists(_mergeResultFilePath))
            {
                File.Delete(_mergeResultFilePath);
            }

            using (FileStream fs = new FileStream(_mergeResultFilePath, FileMode.Create, FileAccess.Write, FileShare.ReadWrite))
            {
                XmlTextWriter xmlTextWriter = new XmlTextWriter(fs, Encoding.ASCII);
                xmlTextWriter.Formatting = Formatting.Indented;

                oldStream.Position = 0;
                XmlTextReader xmlTextReader = new XmlTextReader(_xmlDomResultFilePath);
                XmlTextReader completeDataXmlTextReader = new XmlTextReader(oldStream);
                oldStream = null;
                GC.Collect();

                #region Write the XmlTextReade content to FileStream

                while (xmlTextReader.Read())
                {
                    switch (xmlTextReader.NodeType)
                    {
                        case XmlNodeType.Element:

                            if (xmlTextReader.Name.Contains(_dataHandlerName))
                            {
                                found = true;
                                while (completeDataXmlTextReader.Read())
                                {
                                    if (completeDataXmlTextReader.NodeType != XmlNodeType.EndElement &&
                                        completeDataXmlTextReader.Name.Contains(_dataHandlerName))
                                    {
                                        while (completeDataXmlTextReader.Read())
                                        {
                                            if (completeDataXmlTextReader.NodeType == XmlNodeType.Text)
                                                break;
                                        }
                                        break;
                                    }
                                }
                            }

                            xmlTextWriter.WriteStartElement(xmlTextReader.Prefix, xmlTextReader.LocalName, xmlTextReader.NamespaceURI);
                            xmlTextWriter.WriteAttributes(xmlTextReader, true);

                            if (xmlTextReader.IsEmptyElement)
                                xmlTextWriter.WriteEndElement();

                            break;

                        case XmlNodeType.Text:
                            if (found)
                                xmlTextWriter.WriteString(completeDataXmlTextReader.Value);
                            else
                                xmlTextWriter.WriteString(xmlTextReader.Value);
                            break;

                        case XmlNodeType.Whitespace:
                        case XmlNodeType.SignificantWhitespace:
                            xmlTextWriter.WriteWhitespace(xmlTextReader.Value);
                            break;

                        case XmlNodeType.CDATA:
                            xmlTextWriter.WriteCData(xmlTextReader.Value);
                            break;

                        case XmlNodeType.EntityReference:
                            xmlTextWriter.WriteEntityRef(xmlTextReader.Name);
                            break;

                        case XmlNodeType.XmlDeclaration:
                        case XmlNodeType.ProcessingInstruction:
                            xmlTextWriter.WriteProcessingInstruction(xmlTextReader.Name, xmlTextReader.Value);
                            break;

                        case XmlNodeType.Comment:
                            xmlTextWriter.WriteComment(xmlTextReader.Value);
                            break;

                        case XmlNodeType.EndElement:
                            if (xmlTextReader.Name.Contains(_dataHandlerName))
                                found = false;

                            xmlTextWriter.WriteFullEndElement();
                            break;

                    }

                }

                #endregion

                #region Release Resources

                fs.Flush();
                xmlTextWriter.Close();
                xmlTextReader.Close();
                completeDataXmlTextReader.Close();
                fs.Close();
                fs.Dispose();

                xmlTextReader = null;
                xmlTextWriter = null;
                oldStream = null;
                completeDataXmlTextReader = null;
                GC.Collect();

                #endregion

            }
            return GetMergedResult();
        }

        /// <summary>
        /// Gets the merged result.
        /// </summary>
        /// <returns></returns>
        private static MemoryStream GetMergedResult()
        {
            MemoryStream resultStrem = new MemoryStream();
            using (FileStream fs = new FileStream(_mergeResultFilePath, FileMode.Open, FileAccess.Read))
            {
                byte[] buffer = new byte[fs.Length];
                fs.Read(buffer, 0, (int)fs.Length);
                resultStrem = new MemoryStream(buffer, false);
                buffer = null;

                fs.Flush();
                fs.Close();
                fs.Dispose();
            }
            return resultStrem;
        }

        /// <summary>
        /// Writes to result file.
        /// </summary>
        /// <param name="resultStream">The result stream.</param>
        public static void WriteToResultFile(MemoryStream resultStream)
        {
            if (File.Exists(_xmlDomResultFilePath))
            {
                File.Delete(_xmlDomResultFilePath);
            }

            using (FileStream fs = new FileStream(_xmlDomResultFilePath, FileMode.Create, FileAccess.Write))
            {
                byte[] buffer = new byte[resultStream.Length];
                resultStream.Position = 0;
                resultStream.Read(buffer, 0, (int)resultStream.Length);
                fs.Write(buffer, 0, buffer.Length);
                fs.Flush();
                fs.Close();
            }
        }

        /// <summary>
        /// Deletes the temp files.
        /// </summary>
        public static void DeleteTempFiles()
        {
            if (File.Exists(_filterDataHandlerFilePath))
            {
                File.Delete(_filterDataHandlerFilePath);
            }

            if (File.Exists(_mergeResultFilePath))
            {
                File.Delete(_mergeResultFilePath);
            }

            if (File.Exists(_xmlDomResultFilePath))
            {
                File.Delete(_xmlDomResultFilePath);
            }
        }

        /// <summary>
        /// Gets the data handler nodes.
        /// </summary>
        /// <param name="contentIdBinarydataDictionary">The content id binarydata dictionary.</param>
        public static void GetDataHandlerNodes(Dictionary<string, string> contentIdBinarydataDictionary)
        {
            XmlTextReader xmlTextReader = new XmlTextReader(_mergeResultFilePath);
            string id = string.Empty;

            while (xmlTextReader.Read())
            {
                if (xmlTextReader.Name.Contains(_dataHandlerName) && xmlTextReader.HasAttributes)
                {
                    //Get Id
                    for (int i = 0; i < xmlTextReader.AttributeCount; i++)
                    {
                        xmlTextReader.MoveToAttribute(i);
                        if (xmlTextReader.Name.Contains("id"))
                        {
                            id = "cid:" + Guid.NewGuid();
                            break;
                        }
                    }

                    //Read till DataHandler Content is found
                    while (xmlTextReader.Read())
                    {
                        if (xmlTextReader.NodeType == XmlNodeType.Text)
                        {
                            contentIdBinarydataDictionary.Add(id, xmlTextReader.Value);
                            break;
                        }
                    }
                }
            }
            xmlTextReader = null;
        }

        /// <summary>
        /// Removes the data handler.
        /// </summary>
        public static MemoryStream GetXmlContentWithoutDataHandler()
        {
            bool found = false;
            FileStream fs = new FileStream(_xmlDomResultFilePath, FileMode.Open, FileAccess.Read);
            XmlTextReader xmlTextReader = new XmlTextReader(fs);
            xmlTextReader.WhitespaceHandling = WhitespaceHandling.None;

            MemoryStream outputStream = new MemoryStream();
            XmlTextWriter xmlTextWriter = new XmlTextWriter(outputStream, Encoding.ASCII);
            xmlTextWriter.Formatting = Formatting.Indented;

            #region Write To MemoryStream

            while (xmlTextReader.Read())
            {
                if (xmlTextReader.NodeType != XmlNodeType.EndElement && xmlTextReader.Name.Contains(_dataHandlerName))
                {
                    found = true;
                }

                if (!found)
                {

                    switch (xmlTextReader.NodeType)
                    {
                        case XmlNodeType.Element:
                            xmlTextWriter.WriteStartElement(xmlTextReader.Prefix, xmlTextReader.LocalName, xmlTextReader.NamespaceURI);
                            xmlTextWriter.WriteAttributes(xmlTextReader, true);

                            if (xmlTextReader.IsEmptyElement)
                                xmlTextWriter.WriteEndElement();
                            break;

                        case XmlNodeType.Text:
                            xmlTextWriter.WriteString(xmlTextReader.Value);
                            break;

                        case XmlNodeType.Whitespace:
                        case XmlNodeType.SignificantWhitespace:
                            xmlTextWriter.WriteWhitespace(xmlTextReader.Value);
                            break;

                        case XmlNodeType.CDATA:
                            xmlTextWriter.WriteCData(xmlTextReader.Value);
                            break;

                        case XmlNodeType.EntityReference:
                            xmlTextWriter.WriteEntityRef(xmlTextReader.Name);
                            break;

                        case XmlNodeType.XmlDeclaration:
                        case XmlNodeType.ProcessingInstruction:
                            xmlTextWriter.WriteProcessingInstruction(xmlTextReader.Name, xmlTextReader.Value);
                            break;

                        case XmlNodeType.Comment:
                            xmlTextWriter.WriteComment(xmlTextReader.Value);
                            break;

                        case XmlNodeType.EndElement:
                            xmlTextWriter.WriteFullEndElement();
                            break;

                    }

                }
                else
                {
                    if (xmlTextReader.NodeType == XmlNodeType.EndElement &&
                        xmlTextReader.Name.Contains(_dataHandlerName))
                    {
                        found = false;
                    }
                }
            }
            #endregion

            fs.Flush();
            fs.Close();
            xmlTextWriter.Flush();
            xmlTextReader = null;
            xmlTextWriter = null;
            GC.Collect();

            outputStream.Position = 0;
            return outputStream;
        }
    }
}
