using System;

namespace Microsoft.eResearch.ScientificAddIn.Common
{
    /// <summary>
    /// Event arguments for change of dock position
    /// </summary>
    public class DockPositionChangedEventArgs : EventArgs
    {
        private readonly TaskPaneDockPosition dockPosition;
        private readonly string taskPaneTitle;

        /// <summary>
        /// Initializes a new instance of the <see cref="DockPositionChangedEventArgs"/> class.
        /// </summary>
        /// <param name="dockPosition">The dock position.</param>
        /// <param name="taskPaneName">Name of the task pane.</param>
        public DockPositionChangedEventArgs(TaskPaneDockPosition dockPosition, string taskPaneName)
        {
            this.dockPosition = dockPosition;
            this.taskPaneTitle = taskPaneName;
        }

        /// <summary>
        /// Gets a value indicating the dock position of the originating task pane.
        /// </summary>
        /// <value>The dock position.</value>
        public TaskPaneDockPosition DockPosition
        {
            get { return dockPosition; }
        }

        /// <summary>
        /// Gets the title of the originating task pane.
        /// </summary>
        /// <value>The title of the task pane.</value>
        public string TaskPaneTitle
        {
            get { return taskPaneTitle; }
        }
    }

    /// <summary>
    /// Enumeration for dock position of a custom task pane
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1008:EnumsShouldHaveZeroValue")]
    [FlagsAttribute]
    public enum TaskPaneDockPosition
    {
        /// <summary>
        /// Floating, not docked
        /// </summary>
        Floating = 0,
        /// <summary>
        /// Top of the window
        /// </summary>
        Top = 1,
        /// <summary>
        /// Right side of the window
        /// </summary>
        Right = 2,
        /// <summary>
        /// Bottom of the window
        /// </summary>
        Bottom = 4,
        /// <summary>
        /// Left side of the window
        /// </summary>
        Left = 8
    }
}
