using System;
using MSOffice = Microsoft.Office.Core;

namespace Microsoft.eResearch.ScientificAddIn.Common
{
    /// <summary>
    /// This interface should be implemnted by components that need to 
    /// retrieve the custom XML parts in a word document.
    /// </summary>
    public interface IDocumentStorage
    {
        /// <summary>
        /// Gets the custom XML part by id.
        /// </summary>
        /// <param name="id">The XML part id.</param>
        /// <returns>A Custom Xml Part corrspoding to the ID</returns>
        MSOffice.CustomXMLPart GetCustomXmlPartById(string id);

        /// <summary>
        /// Gets the custom XML part by id.
        /// </summary>
        /// <param name="id">The id.</param>
        /// <param name="documentKey"></param>
        /// <param name="host">The host.</param>
        /// <returns></returns>
        MSOffice.CustomXMLPart GetCustomXmlPartById(string id, string documentKey, IPackageHost host);

        /// <summary>
        /// Gets the custom XML part by GUID.
        /// </summary>
        /// <param name="guid">The GUID.</param>
        /// <returns>A Custom XML part specified by the GUID</returns>
        MSOffice.CustomXMLPart GetCustomXmlPartByGuid(Guid guid);

        /// <summary>
        /// Deletes the custom XML part by id.
        /// </summary>
        /// <param name="id">The id of the XML part.</param>
        void DeleteCustomXmlPartById(string id);

        /// <summary>
        /// Deletes the custom XML part by GUID.
        /// </summary>
        /// <param name="guid">The GUID of the XML part.</param>
        void DeleteCustomXmlPartByGuid(Guid guid);

        /// <summary>
        /// Clears the datastore and removes any trace of it form the serialization media
        /// </summary>
        void Reset();

        /// <summary>
        /// Gets the custom XML part by GUID.
        /// </summary>
        /// <param name="guid">The GUID.</param>
        /// <param name="documentKey">The document key.</param>
        /// <param name="_host">The _host.</param>
        /// <returns></returns>
        Microsoft.Office.Core.CustomXMLPart GetCustomXmlPartByGuid(Guid guid, string documentKey, IPackageHost _host);

        /// <summary>
        /// Sets the next field.
        /// </summary>
        /// <param name="lsid">The lsid.</param>
        /// <param name="next">The next.</param>
        /// <param name="documentKey">The document key.</param>
        /// <param name="host">The host.</param>
        void SetNextField(string lsid, string next, string documentKey, IPackageHost host);

        /// <summary>
        /// Gets the next GUID.
        /// </summary>
        /// <param name="guidin">The guidin.</param>
        /// <param name="documentKey">The document key.</param>
        /// <param name="host">The host.</param>
        /// <returns></returns>
        string GetNextGuid(string guidin, string documentKey, IPackageHost host);

        /// <summary>
        /// Gets the next GUID.
        /// </summary>
        /// <param name="lsidCurrent">The lsid current.</param>
        /// <returns></returns>
        string GetNextGuid(string lsidCurrent);

    }
}
