using Office = Microsoft.Office.Core;

namespace Microsoft.eResearch.ScientificAddIn.Common
{
    /// <summary>
    /// This represents the abstraction of a Scientific Package and is the one that is implemented
    /// by the concrete scientific implementation(Gene Pattern package, Physics package etc)
    /// It requires the concrete implementations to supply the following 3 interfaces
    /// <list type="bullet">
    /// <item><see cref="IPackageHost"/>IPackageHost</item>
    /// <item><see cref="IPackageHost"/>ITaskManager</item>
    /// <item><see cref="IPackageHost"/>IDocumentStorage</item>
    /// </list>
    /// </summary>
    public interface IScientificPackage
    {
        /// <summary>
        /// Gets a ribbon extension from the package.
        /// </summary>
        /// <returns>an object that should be of type Office.IRibbonExtensibility</returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1024:UsePropertiesWhereAppropriate")]
        object GetRibbon();

        /// <summary>
        /// Sets the package host.
        /// </summary>
        /// <param name="host">The host.</param>
        void SetPackageHost(IPackageHost host);

        /// <summary>
        /// Sets the task pane manager for this package. This controls 
        /// all the task panes associated with the package
        /// </summary>
        /// <param name="taskPaneManager">The task pane manager.</param>
        void SetTaskPaneManager(ITaskPaneManager taskPaneManager);

        /// <summary>
        /// Sets the document storage.
        /// </summary>
        /// <param name="documentStorage">The document storage.</param>
        void SetDocumentStorage(IDocumentStorage documentStorage);
    }
}
