using System;
namespace Microsoft.eResearch.ScientificAddIn.Common
{
    ///<summary>
    /// This calls is use data hold data for the ImageSelect event 
    /// defined in <see cref="IPackageHost"/>
    ///</summary>
    public class SelectedImageEventArgs: EventArgs
    {
        private readonly DocumentImage selectedImage;
        private bool isTaskPaneVisible;

        /// <summary>
        /// Gets or sets a value indicating whether this instance is task pane visible.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is task pane visible; otherwise, <c>false</c>.
        /// </value>
        public bool IsTaskPaneVisible
        {
            get { return isTaskPaneVisible; }
            set { isTaskPaneVisible = value; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SelectedImageEventArgs"/> class.
        /// </summary>
        /// <param name="image">The image.</param>
        public SelectedImageEventArgs(DocumentImage image)
        {
            this.selectedImage = image;
        }


        /// <summary>
        /// Gets the selected image.
        /// </summary>
        /// <value>The selected image.</value>
        public DocumentImage SelectedImage
        {
            get { return selectedImage; }
        }
    }

    /// <summary>
    /// Custom Cancel Close Event Args for Word Document
    /// </summary>
    public class CancelCloseEventArgs : EventArgs
    {
        private bool cancel;

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="CancelCloseEventArgs"/> is cancel.
        /// </summary>
        /// <value><c>true</c> if cancel; otherwise, <c>false</c>.</value>
        public bool Cancel
        {
            get { return cancel; }
            set { cancel = value; }
        }
    }

    /// <summary>
    /// Custom Document Save Event Args for Word Document
    /// </summary>
    public class DocumentSaveEventArgs : EventArgs
    {
        private bool cancelSaveDialog;

        /// <summary>
        /// Gets or sets a value indicating whether [cancel save dialog].
        /// </summary>
        /// <value><c>true</c> if [cancel save dialog]; otherwise, <c>false</c>.</value>
        public bool CancelSaveDialog
        {
            get { return cancelSaveDialog; }
            set { cancelSaveDialog = value; }
        }
    }
}
