using System;

namespace Microsoft.eResearch.ScientificAddIn.Common
{
    /// <summary>
    /// Event arguments for change of visibility
    /// </summary>
    public class VisibilityChangedEventArgs : EventArgs
    {
        private readonly bool isVisible;
        private readonly string taskPaneTitle;

        /// <summary>
        /// Initializes a new instance of the <see cref="VisibilityChangedEventArgs"/> class.
        /// </summary>
        /// <param name="isVisible">if set to <c>true</c> the task pane is visible.</param>
        /// <param name="taskPaneName">Name of the task pane.</param>
        public VisibilityChangedEventArgs(bool isVisible, string taskPaneName)
        {
            this.isVisible = isVisible;
            this.taskPaneTitle = taskPaneName;
        }

        /// <summary>
        /// Gets a value indicating whether the originating task pane is visible.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this task pane is visible; otherwise, <c>false</c>.
        /// </value>        
        public bool IsVisible
        {
            get { return isVisible; }
        }

        /// <summary>
        /// Gets the title of the originating task pane.
        /// </summary>
        /// <value>The title of the task pane.</value>
        public string TaskPaneTitle
        {
            get { return taskPaneTitle; }
        }
    }
}
