using System.Windows.Forms;
using Microsoft.Office.Tools;

namespace Microsoft.eResearch.ScientificAddIn
{
    /// <summary>
    /// Interface for return the current window key and adding task panes
    /// 
    /// </summary>
    public interface IWindowContainer
    {
        /// <summary>
        /// Gets the key of the currently active window in Word 2007
        /// </summary>
        /// <value>The current window key.</value>
        string CurrentWindowKey
        {
            get;
        }

        /// <summary>
        /// Adds a new task pane to the current active window in Word 2007
        /// </summary>
        /// <param name="userControl">The user control to be displayed in the CustomTaskPane</param>
        /// <param name="title">The title of the CustomTaskPane.</param>
        /// <returns>A wrapper for the new CustomTaskPane</returns>
        CustomTaskPane AddTaskPane(UserControl userControl, string title);

        /// <summary>
        /// Removes the task panes for the active document/window.
        /// </summary>
        void RemoveTaskPanes();

        /// <summary>
        /// Get a task pane with the given title
        /// </summary>
        /// <param name="title"></param>
        /// <returns></returns>
        CustomTaskPane GetTaskPane(string title);

        /// <summary>
        /// Gets the task pane.
        /// </summary>
        /// <param name="title">The title.</param>
        /// <param name="documentKey">The document key.</param>
        /// <returns></returns>
        CustomTaskPane GetTaskPane(string title, string documentKey);

        /// <summary>
        /// Removes the task pane.
        /// </summary>
        /// <param name="title">The title.</param>
        void RemoveTaskPane(string title);
    }
}
